searchData={"items":[{"type":"module","title":"EdgeDB","doc":"EdgeDB client for Elixir.\n\n`EdgeDB` module provides an API to run a connection pool, query EdgeDB, perform transactions\n  and their rollback.\n\nA simple example of how to use it:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query!(client, \"\"\"\n...(2)>   select v1::Person{\n...(2)>     first_name,\n...(2)>     middle_name,\n...(2)>     last_name\n...(2)>   } filter .last_name =  $last_name;\n...(2)> \"\"\", last_name: \"Radcliffe\")\n#EdgeDB.Set<{#EdgeDB.Object }>\n```","ref":"EdgeDB.html"},{"type":"function","title":"EdgeDB.as_readonly/1","doc":"Mark the client as read-only.\n\nThis function will mark the client as read-only, so any modifying queries will return errors.","ref":"EdgeDB.html#as_readonly/1"},{"type":"function","title":"EdgeDB.child_spec/1","doc":"Creates a child specification for the supervisor to start the EdgeDB pool.\n\nSee `t:EdgeDB.start_option/0` for supported connection options.","ref":"EdgeDB.html#child_spec/1"},{"type":"function","title":"EdgeDB.execute/4","doc":"Execute an EdgeQL command or commands on the client without returning anything.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#execute/4"},{"type":"function","title":"EdgeDB.execute!/4","doc":"Execute an EdgeQL command or commands on the client without returning\n  anything. If an error occurs while executing the query,\n  it will be raised as an `EdgeDB.Error` exception.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#execute!/4"},{"type":"function","title":"EdgeDB.query/4","doc":"Execute the query on the client and return the results as a `{:ok, set}` tuple\n  if successful, where `set` is `EdgeDB.Set`.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, set} = EdgeDB.query(client, \"select 42\")\niex(3)> set\n#EdgeDB.Set<{42}>\n```\n\nIf an error occurs, it will be returned as a `{:error, exception}` tuple\n  where `exception` is `EdgeDB.Error`.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:error, %EdgeDB.Error{} = error} = EdgeDB.query(client, \"select UndefinedType\")\niex(3)> raise error\n** (EdgeDB.Error) InvalidReferenceError: object type or alias 'default::UndefinedType' does not exist\n  ┌─ query:1:8\n  │\n1 │   select UndefinedType\n  │          ^^^^^^^^^^^^^ error\n```\n\nIf a query has arguments, they can be passed as a list for a query with positional arguments\n  or as a list of keywords for a query with named arguments.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, set} = EdgeDB.query(client, \"select  $0\", [42])\niex(3)> set\n#EdgeDB.Set<{42}>\n```\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, set} = EdgeDB.query(client, \"select  $arg\", arg: 42)\niex(3)> set\n#EdgeDB.Set<{42}>\n```","ref":"EdgeDB.html#query/4"},{"type":"function","title":"Automatic retries of read-only queries - EdgeDB.query/4","doc":"If the client is able to recognize the query as a read-only query\n  (i.e. the query does not change the data in the database using `delete`, `insert` or other statements),\n  then the client will try to repeat the query automatically (as long as the query is not executed in a transaction,\n  because then retrying transactions via `EdgeDB.transaction/3` are used).\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query/4-automatic-retries-of-read-only-queries"},{"type":"function","title":"EdgeDB.query!/4","doc":"Execute the query on the client and return the results as `EdgeDB.Set`.\n  If an error occurs while executing the query, it will be raised as\n  as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query!/4"},{"type":"function","title":"EdgeDB.query_json/4","doc":"Execute the query on the client and return the results as a `{:ok, json}` tuple\n  if successful, where `json` is JSON encoded string.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_json/4"},{"type":"function","title":"EdgeDB.query_json!/4","doc":"Execute the query on the client and return the results as JSON encoded string.\n  If an error occurs while executing the query, it will be raised as\n  as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_json!/4"},{"type":"function","title":"EdgeDB.query_required_single/4","doc":"Execute the query on the client and return a singleton-returning result\n  as a `{:ok, result}` tuple.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_required_single/4"},{"type":"function","title":"EdgeDB.query_required_single!/4","doc":"Execute the query on the client and return a singleton-returning result.\n  If an error occurs while executing the query, it will be raised\n  as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_required_single!/4"},{"type":"function","title":"EdgeDB.query_required_single_json/4","doc":"Execute the query on the client and return a singleton-returning result\n  as a `{:ok, json}` tuple.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_required_single_json/4"},{"type":"function","title":"EdgeDB.query_required_single_json!/4","doc":"Execute the query on the client and return a singleton-returning result\n  as JSON string. If an error occurs while executing the query,\n  it will be raised as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_required_single_json!/4"},{"type":"function","title":"EdgeDB.query_single/4","doc":"Execute the query on the client and return an optional singleton-returning\n  result as a `{:ok, result}` tuple.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_single/4"},{"type":"function","title":"EdgeDB.query_single!/4","doc":"Execute the query on the client and return an optional singleton-returning result.\n  If an error occurs while executing the query, it will be raised\n  as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_single!/4"},{"type":"function","title":"EdgeDB.query_single_json/4","doc":"Execute the query on the client and return an optional singleton-returning\n  result as a `{:ok, json}` tuple.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_single_json/4"},{"type":"function","title":"EdgeDB.query_single_json!/4","doc":"Execute the query on the client and return an optional singleton-returning result\n  as JSON encoded string. If an error occurs while executing the query,\n  it will be raised as an `EdgeDB.Error` exception.\n\nFor the general usage, see `EdgeDB.query/4`.\n\nSee `t:EdgeDB.query_option/0` for supported options.","ref":"EdgeDB.html#query_single_json!/4"},{"type":"function","title":"EdgeDB.rollback/2","doc":"Rollback an open transaction.\n\nSee `t:EdgeDB.rollback_option/0` for supported options.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:error, :tx_rollback} =\n...(2)>  EdgeDB.transaction(client, fn tx_conn ->\n...(2)>   EdgeDB.rollback(tx_conn, reason: :tx_rollback)\n...(2)>  end)\n\n```","ref":"EdgeDB.html#rollback/2"},{"type":"function","title":"EdgeDB.start_link/1","doc":"Creates a pool of EdgeDB connections linked to the current process.\n\nIf the first argument is a string, it will be assumed to be the DSN or instance name\n  and passed as `[dsn: dsn]` keyword list to connect.\n\n```iex\niex(1)> {:ok, _client} = EdgeDB.start_link(\"edgedb://edgedb:edgedb@localhost:5656/edgedb\")\n\n```\n\nOtherwise, if the first argument is a list, it will be used as is to connect.\n  See `t:EdgeDB.start_option/0` for supported connection options.\n\n```iex\niex(1)> {:ok, _client} = EdgeDB.start_link(instance: \"edgedb_elixir\")\n\n```","ref":"EdgeDB.html#start_link/1"},{"type":"function","title":"EdgeDB.start_link/2","doc":"Creates a pool of EdgeDB connections linked to the current process.\n\nThe first argument is the string which will be assumed as the DSN and passed as\n  `[dsn: dsn]` keyword list along with other options to connect.\n  See `t:EdgeDB.start_option/0` for supported connection options.\n\n```iex\niex(1)> {:ok, _client} = EdgeDB.start_link(\"edgedb://edgedb:edgedb@localhost:5656/edgedb\", tls_security: :insecure)\n\n```","ref":"EdgeDB.html#start_link/2"},{"type":"function","title":"EdgeDB.transaction/3","doc":"Open a retryable transaction loop.\n\nEdgeDB clients support transactions that are robust to network errors, server failure, and\n  some transaction conflicts. For more information see\n  [RFC](https://github.com/edgedb/rfcs/blob/master/text/1004-transactions-api.rst).\n\nThe result of the transaction is the `{:ok, result}` tuple, where `result`\n  is the result of the `callback` function executed in the transaction.\n\nTo rollback an open transaction, use `EdgeDB.rollback/2`.\n\n`EdgeDB.transaction/3` calls **cannot** be nested more than once.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, tickets} = EdgeDB.transaction(client, fn client ->\n...(2)>  EdgeDB.query!(client, \"insert v1::Ticket{ number := 2}\")\n...(2)>  EdgeDB.query!(client, \"select v1::Ticket\")\n...(2)> end)\niex(3)> tickets\n#EdgeDB.Set<{#EdgeDB.Object<>}>\n```\n\nSee `t:EdgeDB.transaction_option/0` for supported options.","ref":"EdgeDB.html#transaction/3"},{"type":"function","title":"EdgeDB.with_client_state/2","doc":"Returns client with adjusted state.\n\nSee `EdgeDB.with_default_module/2`, `EdgeDB.with_module_aliases/2`/`EdgeDB.without_module_aliases/2`,\n  `EdgeDB.with_config/2`/`EdgeDB.without_config/2`, `EdgeDB.with_globals/2`/`EdgeDB.without_globals/2`\n  for more information.","ref":"EdgeDB.html#with_client_state/2"},{"type":"function","title":"EdgeDB.with_config/2","doc":"Returns client with adjusted session config.\n\nThis is equivalent to using the `configure session set` command.","ref":"EdgeDB.html#with_config/2"},{"type":"function","title":"EdgeDB.with_default_module/2","doc":"Returns client with adjusted default module.\n\nThis is equivalent to using the `set module` command,\n  or using the `reset module` command when giving `nil`.","ref":"EdgeDB.html#with_default_module/2"},{"type":"function","title":"EdgeDB.with_globals/2","doc":"Returns client with adjusted global values.\n\nThis is equivalent to using the `set global` command.","ref":"EdgeDB.html#with_globals/2"},{"type":"function","title":"EdgeDB.with_module_aliases/2","doc":"Returns client with adjusted module aliases.\n\nThis is equivalent to using the `set alias` command.","ref":"EdgeDB.html#with_module_aliases/2"},{"type":"function","title":"EdgeDB.with_retry_options/2","doc":"Configure the client so that futher transactions retries are executed with custom retries options.\n\nSee `t:EdgeDB.Client.retry_option/0` for supported options.","ref":"EdgeDB.html#with_retry_options/2"},{"type":"function","title":"EdgeDB.with_transaction_options/2","doc":"Configure the client so that futher transactions are executed with custom transaction options.\n\nSee `t:EdgeDB.transaction_option/0` for supported options.","ref":"EdgeDB.html#with_transaction_options/2"},{"type":"function","title":"EdgeDB.without_config/2","doc":"Returns client without specified session config.\n\nThis is equivalent to using the `configure session reset` command.","ref":"EdgeDB.html#without_config/2"},{"type":"function","title":"EdgeDB.without_globals/2","doc":"Returns client without specified globals.\n\nThis is equivalent to using the `reset global` command.","ref":"EdgeDB.html#without_globals/2"},{"type":"function","title":"EdgeDB.without_module_aliases/2","doc":"Returns client without specified module aliases.\n\nThis is equivalent to using the `reset alias` command.","ref":"EdgeDB.html#without_module_aliases/2"},{"type":"type","title":"EdgeDB.client/0","doc":"Connection pool process name, pid or the separate structure\n  that allows adjusted configuration for queries executed on the connection.\n\nSee `EdgeDB.as_readonly/1`, `EdgeDB.with_retry_options/2`, `EdgeDB.with_transaction_options/2`\n  for more information.","ref":"EdgeDB.html#t:client/0"},{"type":"type","title":"EdgeDB.connect_option/0","doc":"Parameters for connecting to an EdgeDB instance and configuring the connection itself.\n\nEdgeDB clients allow a very flexible way to define how to connect to an instance.\n  For more information, see [the EdgeDB documentation on connection parameters](https://www.edgedb.com/docs/reference/connection#ref-reference-connection-granular).\n\nSupported options:\n\n  * `:dsn` - DSN that defines the primary information that can be used to connect to the instance.\n  * `:credentials` - a JSON string containing the instance parameters to connect.\n  * `:credentials_file` - the path to the instance credentials file containing the instance parameters to connect to.\n  * `:host` - the host name of the instance to connect to.\n  * `:port` - the port number of the instance to connect to.\n  * `:database` - the name of the database to connect to.\n  * `:branch` - the name of the branch to connect to.\n  * `:user` - the user name to connect to.\n  * `:password` - the user password to connect.\n  * `:secret_key` - the secret key to be used for authentication.\n  * `:tls_ca` - TLS certificate to be used when connecting to the instance.\n  * `:tls_ca_path` - the path to the TLS certificate to be used when connecting to the instance.\n  * `:tls_security` - security mode for the TLS connection. See `t:EdgeDB.tls_security/0`.\n  * `:tls_server_name` - server name (SNI) to be passed to the TLS connection.\n  * `:timeout` - timeout for TCP operations with the database, such as connecting to it, sending or receiving data.\n  * `:command_timeout` - *not in use right now and added for compatibility with other clients*.\n  * `:server_settings` - *not in use right now and added for compatibility with other clients*.\n  * `:tcp` - options for the TCP connection.\n  * `:ssl` - options for TLS connection.\n  * `:transaction` - options for EdgeDB transactions, which correspond to\n    [the EdgeQL transaction statement](https://www.edgedb.com/docs/reference/edgeql/tx_start#statement::start-transaction).\n    See `t:EdgeDB.Client.transaction_option/0`.\n  * `:retry` - options to retry transactions in case of errors. See `t:EdgeDB.Client.retry_option/0`.\n  * `:codecs` - list of custom codecs for EdgeDB scalars.\n  * `:connection` - module that implements the `DBConnection` behavior for EdgeDB.\n    For tests, it's possible to use `EdgeDB.Sandbox` to support automatic rollback after tests are done.\n  * `:max_concurrency` - maximum number of pool connections, despite what EdgeDB recommends.\n  * `:client_state` - an `EdgeDB.Client.State` struct that will be used in queries by default.","ref":"EdgeDB.html#t:connect_option/0"},{"type":"type","title":"EdgeDB.query_option/0","doc":"Options for `EdgeDB.query*/4` functions.\n\nThese options can be used with the following functions:\n\n  * `EdgeDB.query/4`\n  * `EdgeDB.query!/4`\n  * `EdgeDB.query_single/4`\n  * `EdgeDB.query_single!/4`\n  * `EdgeDB.query_required_single/4`\n  * `EdgeDB.query_required_single!/4`\n  * `EdgeDB.query_json/4`\n  * `EdgeDB.query_json!/4`\n  * `EdgeDB.query_single_json/4`\n  * `EdgeDB.query_single_json!/4`\n  * `EdgeDB.query_required_single_json/4`\n  * `EdgeDB.query_required_single_json!/4`\n\nSupported options:\n\n  * `:cardinality` - expected number of items in set.\n  * `:output_format` - preferred format of query result.\n  * `:retry` - options for read-only queries retries.\n  * other - check `t:DBConnection.option/0`.","ref":"EdgeDB.html#t:query_option/0"},{"type":"type","title":"EdgeDB.result/0","doc":"The result that will be returned if the `EdgeDB.query*/4` function succeeds.","ref":"EdgeDB.html#t:result/0"},{"type":"type","title":"EdgeDB.rollback_option/0","doc":"Options for `EdgeDB.rollback/2`.\n\nSupported options:\n\n  * `:reason` - the reason for the rollback. Will be returned from `EdgeDB.transaction/3`\n    as a `{:error, reason}` tuple in case block execution is interrupted.","ref":"EdgeDB.html#t:rollback_option/0"},{"type":"type","title":"EdgeDB.start_option/0","doc":"Options for `EdgeDB.start_link/1`.\n\nSee `t:EdgeDB.connect_option/0` and `t:DBConnection.start_option/0`.","ref":"EdgeDB.html#t:start_option/0"},{"type":"type","title":"EdgeDB.tls_security/0","doc":"Security modes for TLS connection to EdgeDB server.\n\nFor more information, see [the EdgeDB documentation on connection parameters](https://www.edgedb.com/docs/reference/connection#ref-reference-connection-granular).\n\nSupported options:\n\n  * `:insecure` - trust a self-signed or user-signed TLS certificate, which is useful for local development.\n  * `:no_host_verification` - verify the TLS certificate, but not the host name.\n  * `:strict` - verify both the TLS certificate and the hostname.\n  * `:default` - the same as `:strict`.","ref":"EdgeDB.html#t:tls_security/0"},{"type":"type","title":"EdgeDB.transaction_option/0","doc":"Options for `EdgeDB.transaction/3`.\n\nSee `t:EdgeDB.Client.transaction_option/0`, `t:EdgeDB.Client.retry_option/0`\n  and `t:DBConnection.option/0`.","ref":"EdgeDB.html#t:transaction_option/0"},{"type":"module","title":"EdgeDB.Client","doc":"Сlient is a structure that stores a custom configuration to execute EdgeQL queries\n  and has a reference to a connection or pool of connections.\n\nAfter starting the pool via `EdgeDB.start_link/1` or siblings,\n  the client instance for the pool will be implicitly registered.\n\nIn case you want to change the behavior of your queries, you will use the `EdgeDB.Client`,\n  which is acceptable by all `EdgeDB` API and will be provided to you in a callback\n  in the `EdgeDB.transaction/3` function.","ref":"EdgeDB.Client.html"},{"type":"type","title":"EdgeDB.Client.retry_option/0","doc":"Options for transactions and read-only queries retries.\n\nSee `EdgeDB.transaction/3`.\n\nSupported options:\n\n  * `:transaction_conflict` - the rule that will be used in case of any transaction conflict.\n  * `:network_error` - rule which will be used when any network error occurs on the client.","ref":"EdgeDB.Client.html#t:retry_option/0"},{"type":"type","title":"EdgeDB.Client.retry_rule/0","doc":"Options for a retry rule for transactions retries.\n\nSee `EdgeDB.transaction/3`.\n\nSupported options:\n\n  * `:attempts` - the number of attempts to retry the transaction in case of an error.\n  * `:backoff` - function to determine the backoff before the next attempt to run a transaction.","ref":"EdgeDB.Client.html#t:retry_rule/0"},{"type":"type","title":"EdgeDB.Client.t/0","doc":"Client is structure with stored configuration for executing EdgeQL queries\n  and reference to pool or connection.\n\nFields:\n\n  * `:conn` - reference to connection or pool of connections.\n  * `:readonly` - flag specifying that the client is read-only.\n  * `:transaction_options` - options for EdgeDB transactions.\n  * `:retry_options` - options for a retry rule for transactions retries.\n  * `:state` - execution context that affects the execution of EdgeQL commands.","ref":"EdgeDB.Client.html#t:t/0"},{"type":"type","title":"EdgeDB.Client.transaction_option/0","doc":"Options for EdgeDB transactions.\n\nThese options are responsible for building the appropriate EdgeQL statement to start transactions and\n  they correspond to [the EdgeQL transaction statement](https://www.edgedb.com/docs/reference/edgeql/tx_start#statement::start-transaction).\n\nSupported options:\n\n  * `:isolation` - If `:serializable` is used, the built statement will use the `isolation serializable` mode.\n    Currently only `:serializable` is supported by this client and EdgeDB.\n  * `:readonly` - if set to `true` then the built statement will use `read only` mode,\n    otherwise `read write` will be used. The default is `false`.\n  * `:deferrable` - if set to `true` then the built statement will use `deferrable` mode,\n    otherwise `not deferrable` will be used. The default is `false`.","ref":"EdgeDB.Client.html#t:transaction_option/0"},{"type":"module","title":"EdgeDB.Client.State","doc":"State for the client is an execution context that affects the execution of EdgeQL commands in different ways:\n\n  1. default module.\n  2. module aliases.\n  3. session config.\n  4. global values.\n\nThe most convenient way to work with the state is to use the `EdgeDB` API to change a required part of\n  the state.\n\nSee `EdgeDB.with_client_state/2`, `EdgeDB.with_default_module/2`,\n  `EdgeDB.with_module_aliases/2`/`EdgeDB.without_module_aliases/2`,\n  `EdgeDB.with_config/2`/`EdgeDB.without_config/2` and\n  `EdgeDB.with_globals/2`/`EdgeDB.without_globals/2` for more information.","ref":"EdgeDB.Client.State.html"},{"type":"function","title":"EdgeDB.Client.State.with_config/2","doc":"Returns an `EdgeDB.Client.State` with adjusted session config.\n\nThis is equivalent to using the `configure session set` command.","ref":"EdgeDB.Client.State.html#with_config/2"},{"type":"function","title":"EdgeDB.Client.State.with_default_module/2","doc":"Returns an `EdgeDB.Client.State` with adjusted default module.\n\nThis is equivalent to using the `set module` command,\n  or using the `reset module` command when giving `nil`.","ref":"EdgeDB.Client.State.html#with_default_module/2"},{"type":"function","title":"EdgeDB.Client.State.with_globals/2","doc":"Returns an `EdgeDB.Client.State` with adjusted global values.\n\nThis is equivalent to using the `set global` command.","ref":"EdgeDB.Client.State.html#with_globals/2"},{"type":"function","title":"EdgeDB.Client.State.with_module_aliases/2","doc":"Returns an `EdgeDB.Client.State` with adjusted module aliases.\n\nThis is equivalent to using the `set alias` command.","ref":"EdgeDB.Client.State.html#with_module_aliases/2"},{"type":"function","title":"EdgeDB.Client.State.without_config/2","doc":"Returns an `EdgeDB.Client.State` without specified session config.\n\nThis is equivalent to using the `configure session reset` command.","ref":"EdgeDB.Client.State.html#without_config/2"},{"type":"function","title":"EdgeDB.Client.State.without_globals/2","doc":"Returns an `EdgeDB.Client.State` without specified globals.\n\nThis is equivalent to using the `reset global` command.","ref":"EdgeDB.Client.State.html#without_globals/2"},{"type":"function","title":"EdgeDB.Client.State.without_module_aliases/2","doc":"Returns an `EdgeDB.Client.State` without specified module aliases.\n\nThis is equivalent to using the `reset alias` command.","ref":"EdgeDB.Client.State.html#without_module_aliases/2"},{"type":"type","title":"EdgeDB.Client.State.config/0","doc":"Config to be passed to `EdgeDB.with_config/2`.","ref":"EdgeDB.Client.State.html#t:config/0"},{"type":"type","title":"EdgeDB.Client.State.config_key/0","doc":"Keys that EdgeDB accepts for changing client behaviour configuration.\n\nThe meaning and acceptable values can be found in the\n  [docs](https://www.edgedb.com/docs/stdlib/cfg#client-connections).","ref":"EdgeDB.Client.State.html#t:config_key/0"},{"type":"opaque","title":"EdgeDB.Client.State.t/0","doc":"State for the client is an execution context that affects the execution of EdgeQL commands.","ref":"EdgeDB.Client.State.html#t:t/0"},{"type":"module","title":"EdgeDB.Sandbox","doc":"Custom connection for tests that involve modifying the database through the driver.\n\nThis connection, when started, wraps the actual connection to EdgeDB into a transaction using\n  the `start transaction` statement. And then further calls to `EdgeDB.transaction/3` will result\n  in executing `declare savepoint` statement instead of `start transaction`.\n\nTo use this module in tests, change the configuration of the `:edgedb` application in the `config/test.exs`:\n\n```elixir\nconfig :edgedb,\n  connection: EdgeDB.Sandbox\n```\n\nThen modify the test case to initialize the sandbox when you run the test and to clean the sandbox\n  at the end of the test:\n\n```elixir\ndefmodule MyApp.TestCase do\n  use ExUnit.CaseTemplate\n\n  # other stuff for this case (e.g. Phoenix setup, Plug configuration, etc.)\n\n  setup _context do\n    EdgeDB.Sandbox.initialize(MyApp.EdgeDB)\n\n    on_exit(fn ->\n      EdgeDB.Sandbox.clean(MyApp.EdgeDB)\n    end)\n\n    :ok\n  end\nend\n```","ref":"EdgeDB.Sandbox.html"},{"type":"function","title":"EdgeDB.Sandbox.clean/1","doc":"Release the connection transaction.","ref":"EdgeDB.Sandbox.html#clean/1"},{"type":"function","title":"EdgeDB.Sandbox.initialize/1","doc":"Wrap a connection in a transaction.","ref":"EdgeDB.Sandbox.html#initialize/1"},{"type":"module","title":"EdgeDB.ConfigMemory","doc":"An immutable value represeting an EdgeDB `cfg::memory` value as a quantity of memory storage.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> mem = EdgeDB.query_required_single!(client, \"select  '5KiB'\")\n#EdgeDB.ConfigMemory<\"5KiB\">\niex(3)> EdgeDB.ConfigMemory.bytes(mem)\n5120\n```","ref":"EdgeDB.ConfigMemory.html"},{"type":"function","title":"EdgeDB.ConfigMemory.bytes/1","doc":"Get a quantity of memory storage in bytes.","ref":"EdgeDB.ConfigMemory.html#bytes/1"},{"type":"function","title":"EdgeDB.ConfigMemory.new/1","doc":"Create a new config memory value.","ref":"EdgeDB.ConfigMemory.html#new/1"},{"type":"opaque","title":"EdgeDB.ConfigMemory.t/0","doc":"An immutable value represeting an EdgeDB `cfg::memory` value as a quantity of memory storage.","ref":"EdgeDB.ConfigMemory.html#t:t/0"},{"type":"module","title":"EdgeDB.DateDuration","doc":"An immutable value represeting an EdgeDB `cal::date_duration` value.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query_required_single!(client, \"select  '1 year 2 days'\")\n#EdgeDB.DateDuration<\"P1Y2D\">\n```","ref":"EdgeDB.DateDuration.html"},{"type":"type","title":"EdgeDB.DateDuration.t/0","doc":"An immutable value represeting an EdgeDB `cal::date_duration` value.\n\nFields:\n\n  * `:days` - number of days.\n  * `:months` - number of months.","ref":"EdgeDB.DateDuration.html#t:t/0"},{"type":"module","title":"EdgeDB.MultiRange","doc":"A value representing a collection of ranges.\n\n`EdgeDB.MultiRange` implements `Enumerable` protocol for iterating over the collection.\n  Each range in the collection is an instance of the `t:EdgeDB.Range.t/0` struct.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query_required_single!(client, \"select multirange([range(1, 10)])\")\n#EdgeDB.MultiRange<[#EdgeDB.Range<[1, 10)>]>\n```","ref":"EdgeDB.MultiRange.html"},{"type":"function","title":"EdgeDB.MultiRange.new/0","doc":"Create a new multirange.","ref":"EdgeDB.MultiRange.html#new/0"},{"type":"function","title":"EdgeDB.MultiRange.new/1","doc":"Create a new multirange from enumerable.","ref":"EdgeDB.MultiRange.html#new/1"},{"type":"type","title":"EdgeDB.MultiRange.t/0","doc":"A value of `t:EdgeDB.MultiRange.value/0` type representing a collection of intervals of values.","ref":"EdgeDB.MultiRange.html#t:t/0"},{"type":"opaque","title":"EdgeDB.MultiRange.t/1","doc":"A value of `t:EdgeDB.MultiRange.value/0` type representing a collection of intervals of values.","ref":"EdgeDB.MultiRange.html#t:t/1"},{"type":"type","title":"EdgeDB.MultiRange.value/0","doc":"A type that is acceptable by EdgeDB ranges.","ref":"EdgeDB.MultiRange.html#t:value/0"},{"type":"module","title":"EdgeDB.NamedTuple","doc":"An immutable value representing an EdgeDB named tuple value.\n\n`EdgeDB.NamedTuple` implements `Access` behavior to access fields\n  by index or key and `Enumerable` protocol for iterating over tuple values.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> nt = EdgeDB.query_required_single!(client, \"select (a := 1, b := 'a', c := [3])\")\n#EdgeDB.NamedTuple \niex(3)> nt[:b]\n\"a\"\niex(4)> nt[\"c\"]\n[3]\niex(4)> nt[0]\n1\n```","ref":"EdgeDB.NamedTuple.html"},{"type":"function","title":"EdgeDB.NamedTuple.keys/1","doc":"Get named tuple keys.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> nt = EdgeDB.query_required_single!(client, \"select (a := 1, b := 'a', c := [3])\")\niex(3)> EdgeDB.NamedTuple.keys(nt)\n[\"a\", \"b\", \"c\"]\n```","ref":"EdgeDB.NamedTuple.html#keys/1"},{"type":"function","title":"EdgeDB.NamedTuple.to_map/1","doc":"Convert a named tuple into a regular map.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> nt = EdgeDB.query_required_single!(client, \"select (a := 1, b := 'a', c := [3])\")\niex(3)> EdgeDB.NamedTuple.to_map(nt)\n%{\"a\" => 1, \"b\" => \"a\", \"c\" => [3]}\n```","ref":"EdgeDB.NamedTuple.html#to_map/1"},{"type":"function","title":"EdgeDB.NamedTuple.to_tuple/1","doc":"Convert a named tuple to a regular erlang tuple.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> nt = EdgeDB.query_required_single!(client, \"select (a := 1, b := 'a', c := [3])\")\niex(3)> EdgeDB.NamedTuple.to_tuple(nt)\n{1, \"a\", [3]}\n```","ref":"EdgeDB.NamedTuple.html#to_tuple/1"},{"type":"opaque","title":"EdgeDB.NamedTuple.t/0","doc":"An immutable value representing an EdgeDB named tuple value.","ref":"EdgeDB.NamedTuple.html#t:t/0"},{"type":"module","title":"EdgeDB.Object","doc":"An immutable representation of an object instance returned from a query.\n\n`EdgeDB.Object` implements `Access` behavior to access properties by key.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> object =\n...(2)>  EdgeDB.query_required_single!(client, \"\"\"\n...(2)>   select schema::ObjectType{\n...(2)>     name\n...(2)>   }\n...(2)>   filter .name = 'std::Object'\n...(2)>   limit 1\n...(2)>  \"\"\")\n#EdgeDB.Object \niex(3)> object[:name]\n\"std::Object\"\n```","ref":"EdgeDB.Object.html"},{"type":"module","title":"Links and links properties - EdgeDB.Object","doc":"In EdgeDB, objects can have links to other objects or a set of objects.\n  You can use the same syntax to access links values as for object properties.\n  Links can also have their own properties (denoted as `@ ` in EdgeQL syntax).\n  You can use the same property name as in the query to access them from the links.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> object =\n...(2)>  EdgeDB.query_required_single!(client, \"\"\"\n...(2)>   select schema::Property {\n...(2)>       name,\n...(2)>       annotations: {\n...(2)>         name,\n...(2)>         @value\n...(2)>       }\n...(2)>   }\n...(2)>   filter .name = 'listen_port' and .source.name = 'cfg::Config'\n...(2)>   limit 1\n...(2)>  \"\"\")\n#EdgeDB.Object }>>\niex(3)> annotations = object[:annotations]\n#EdgeDB.Set<{#EdgeDB.Object }>\niex(4)> link = Enum.at(annotations, 0)\n#EdgeDB.Object \niex(5)> link[\"@value\"]\n\"true\"\n```","ref":"EdgeDB.Object.html#module-links-and-links-properties"},{"type":"function","title":"EdgeDB.Object.fields/2","doc":"Get object fields names (properties, links and link propries) as list of strings.\n\nSee `t:EdgeDB.Object.fields_option/0` for supported options.","ref":"EdgeDB.Object.html#fields/2"},{"type":"function","title":"EdgeDB.Object.id/1","doc":"Get an object ID if it was returned from the query.","ref":"EdgeDB.Object.html#id/1"},{"type":"function","title":"EdgeDB.Object.link_properties/1","doc":"Get object link propeties names as list.","ref":"EdgeDB.Object.html#link_properties/1"},{"type":"function","title":"EdgeDB.Object.links/1","doc":"Get object links names as list.","ref":"EdgeDB.Object.html#links/1"},{"type":"function","title":"EdgeDB.Object.properties/2","doc":"Get object properties names as list.\n\nSee `t:EdgeDB.Object.properties_option/0` for supported options.","ref":"EdgeDB.Object.html#properties/2"},{"type":"function","title":"EdgeDB.Object.to_map/1","doc":"Convert an object into a regular map.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> object =\n...(2)>  EdgeDB.query_required_single!(client, \"\"\"\n...(2)>   select schema::Property {\n...(2)>       name,\n...(2)>       annotations: {\n...(2)>         name,\n...(2)>         @value\n...(2)>       }\n...(2)>   }\n...(2)>   filter .name = 'listen_port' and .source.name = 'cfg::Config'\n...(2)>   limit 1\n...(2)>  \"\"\")\niex(3)> EdgeDB.Object.to_map(object)\n%{\"name\" => \"listen_port\", \"annotations\" => [%{\"name\" => \"cfg::system\", \"@value\" => \"true\"}]}\n```","ref":"EdgeDB.Object.html#to_map/1"},{"type":"type","title":"EdgeDB.Object.fields_option/0","doc":"Options for `EdgeDB.Object.fields/2`\n\nSupported options:\n\n  * `:properties` - flag to include object properties in returning list. The default is `true`.\n  * `:links` - flag to include object links in returning list. The default is `true`.\n  * `:link_properies` - flag to include object link properties in returning list. The default is `true`.\n  * `:id` - flag to include implicit `:id` in returning list. The default is `false`.\n  * `:implicit` - flag to include implicit fields (like `:id` or `:__tid__`) in returning list.\n    The default is `false`.","ref":"EdgeDB.Object.html#t:fields_option/0"},{"type":"type","title":"EdgeDB.Object.properties_option/0","doc":"Options for `EdgeDB.Object.properties/2`\n\nSupported options:\n\n  * `:id` - flag to include implicit `:id` in returning list. The default is `false`.\n  * `:implicit` - flag to include implicit properties (like `:id` or `:__tid__`) in returning list.\n    The default is `false`.","ref":"EdgeDB.Object.html#t:properties_option/0"},{"type":"opaque","title":"EdgeDB.Object.t/0","doc":"An immutable representation of an object instance returned from a query.","ref":"EdgeDB.Object.html#t:t/0"},{"type":"type","title":"EdgeDB.Object.uuid/0","doc":"UUID value.","ref":"EdgeDB.Object.html#t:uuid/0"},{"type":"module","title":"EdgeDB.Range","doc":"A value representing some interval of values.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query_required_single!(client, \"select range(1, 10)\")\n#EdgeDB.Range<[1, 10)>\n```","ref":"EdgeDB.Range.html"},{"type":"function","title":"EdgeDB.Range.empty/0","doc":"Create an empty range.\n\n```iex\niex(1)> EdgeDB.Range.empty()\n#EdgeDB.Range \n```","ref":"EdgeDB.Range.html#empty/0"},{"type":"function","title":"EdgeDB.Range.new/3","doc":"Create new range.\n\n```iex\niex(1)> EdgeDB.Range.new(1.1, 3.3, inc_upper: true)\n#EdgeDB.Range<[1.1, 3.3]>\n```","ref":"EdgeDB.Range.html#new/3"},{"type":"type","title":"EdgeDB.Range.creation_option/0","doc":"Options for `EdgeDB.Range.new/3` function.\n\nSupported options:\n\n  * `:inc_lower` - flag whether the created range should strictly include the lower boundary.\n  * `:inc_upper` - flag whether the created range should strictly include the upper boundary.\n  * `:empty` - flag to create an empty range.","ref":"EdgeDB.Range.html#t:creation_option/0"},{"type":"type","title":"EdgeDB.Range.t/0","doc":"A value of `t:EdgeDB.Range.value/0` type representing some interval of values.","ref":"EdgeDB.Range.html#t:t/0"},{"type":"type","title":"EdgeDB.Range.t/1","doc":"A value of `t:EdgeDB.Range.value/0` type representing some interval of values.\n\nFields:\n\n  * `:lower` - data for the lower range boundary.\n  * `:upper` - data for the upper range boundary.\n  * `:inc_lower` - flag whether the range should strictly include the lower boundary.\n  * `:inc_upper` - flag whether the range should strictly include the upper boundary.\n  * `:is_empty` - flag for an empty range.","ref":"EdgeDB.Range.html#t:t/1"},{"type":"type","title":"EdgeDB.Range.value/0","doc":"A type that is acceptable by EdgeDB ranges.","ref":"EdgeDB.Range.html#t:value/0"},{"type":"module","title":"EdgeDB.RelativeDuration","doc":"An immutable value represeting an EdgeDB `cal::relative_duration` value.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query_required_single!(client, \"select  '45.6 seconds'\")\n#EdgeDB.RelativeDuration<\"PT45.6S\">\n```","ref":"EdgeDB.RelativeDuration.html"},{"type":"type","title":"EdgeDB.RelativeDuration.t/0","doc":"An immutable value represeting an EdgeDB `cal::relative_duration` value.\n\nFields:\n\n  * `:months` - number of months.\n  * `:days` - number of days.\n  * `:microseconds` - number of microseconds.","ref":"EdgeDB.RelativeDuration.html#t:t/0"},{"type":"module","title":"EdgeDB.Set","doc":"A representation of an immutable set of values returned by a query.\n  Nested sets in the result are also returned as `EdgeDB.Set` objects.\n\n`EdgeDB.Set` implements `Enumerable` protocol for iterating over set values.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> set =\n...(2)>  EdgeDB.query!(client, \"\"\"\n...(2)>   select schema::ObjectType{\n...(2)>     name\n...(2)>   }\n...(2)>   filter .name IN {'std::BaseObject', 'std::Object', 'std::FreeObject'}\n...(2)>   order by .name\n...(2)>  \"\"\")\niex(3)> set\n#EdgeDB.Set<{#EdgeDB.Object , #EdgeDB.Object , #EdgeDB.Object }>\n```","ref":"EdgeDB.Set.html"},{"type":"function","title":"EdgeDB.Set.empty?/1","doc":"Check if set is empty.\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> set = EdgeDB.query!(client, \"select v1::Ticket\")\niex(3)> EdgeDB.Set.empty?(set)\ntrue\n```","ref":"EdgeDB.Set.html#empty?/1"},{"type":"opaque","title":"EdgeDB.Set.t/0","doc":"A representation of an immutable set of values returned by a query.","ref":"EdgeDB.Set.html#t:t/0"},{"type":"protocol","title":"EdgeDB.Protocol.Codec","doc":"A codec knows how to work with the internal binary data from EdgeDB.\nThe binary protocol specification for the codecs can be found in\n  [the relevant part of the EdgeDB documentation](https://www.edgedb.com/docs/reference/protocol).\nUseful links for codec developers:\n\n  * [EdgeDB datatypes used in data descriptions](https://www.edgedb.com/docs/reference/protocol/index#conventions-and-data-types).\n  * [EdgeDB data wire formats](https://www.edgedb.com/docs/reference/protocol/dataformats).\n  * [Built-in EdgeDB codec implementations](https://github.com/edgedb/edgedb-elixir/tree/master/lib/edgedb/protocol/codecs).\n  * [Custom codecs implementations](https://github.com/edgedb/edgedb-elixir/tree/master/test/edgedb/protocol/codecs/custom).\n  * Guide to developing custom codecs on [hex.pm](https://hexdocs.pm/edgedb/custom-codecs.html)\n      or on [edgedb.com](https://www.edgedb.com/docs/clients/elixir/custom-codecs).","ref":"EdgeDB.Protocol.Codec.html"},{"type":"function","title":"EdgeDB.Protocol.Codec.decode/3","doc":"Function that can decode EdgeDB binary format into an entity.","ref":"EdgeDB.Protocol.Codec.html#decode/3"},{"type":"function","title":"EdgeDB.Protocol.Codec.encode/3","doc":"Function that can encode an entity to EdgeDB binary format.","ref":"EdgeDB.Protocol.Codec.html#encode/3"},{"type":"type","title":"EdgeDB.Protocol.Codec.id/0","doc":"Codec ID.","ref":"EdgeDB.Protocol.Codec.html#t:id/0"},{"type":"type","title":"EdgeDB.Protocol.Codec.t/0","doc":"All the types that implement this protocol.","ref":"EdgeDB.Protocol.Codec.html#t:t/0"},{"type":"module","title":"EdgeDB.Protocol.CodecStorage","doc":"A storage for each codec that the connection knows how to decode.","ref":"EdgeDB.Protocol.CodecStorage.html"},{"type":"function","title":"EdgeDB.Protocol.CodecStorage.get/2","doc":"Find a codec in the storage by ID.","ref":"EdgeDB.Protocol.CodecStorage.html#get/2"},{"type":"function","title":"EdgeDB.Protocol.CodecStorage.get_by_name/2","doc":"Find a codec in the storage by type name.","ref":"EdgeDB.Protocol.CodecStorage.html#get_by_name/2"},{"type":"type","title":"EdgeDB.Protocol.CodecStorage.t/0","doc":"A storage for each codec that the connection knows how to decode.","ref":"EdgeDB.Protocol.CodecStorage.html#t:t/0"},{"type":"behaviour","title":"EdgeDB.Protocol.CustomCodec","doc":"Behaviour for custom scalar codecs.\n\nSee custom codecs development guide on [hex.pm](https://hexdocs.pm/edgedb/custom-codecs.html)\n  or on [edgedb.com](https://www.edgedb.com/docs/clients/elixir/custom-codecs) for more information.","ref":"EdgeDB.Protocol.CustomCodec.html"},{"type":"callback","title":"EdgeDB.Protocol.CustomCodec.name/0","doc":"Get name for type that can be decoded by codec.","ref":"EdgeDB.Protocol.CustomCodec.html#c:name/0"},{"type":"callback","title":"EdgeDB.Protocol.CustomCodec.new/0","doc":"Initialize custom codec.","ref":"EdgeDB.Protocol.CustomCodec.html#c:new/0"},{"type":"module","title":"EdgeDB.Protocol.Enums","doc":"Definition for enumerations used in EdgeDB protocol.","ref":"EdgeDB.Protocol.Enums.html"},{"type":"type","title":"EdgeDB.Protocol.Enums.capabilities/0","doc":"Query capabilities.","ref":"EdgeDB.Protocol.Enums.html#t:capabilities/0"},{"type":"type","title":"EdgeDB.Protocol.Enums.capability/0","doc":"Query capabilities.\n\nValues:\n\n  * `:readonly` - query is read-only.\n  * `:modifications` - query is not read-only.\n  * `:session_config` - query contains session config change.\n  * `:transaction` - query contains start/commit/rollback of transaction or savepoint manipulation.\n  * `:ddl` - query contains DDL.\n  * `:persistent_config` - server or database config change.\n  * `:all` - all possible capabilities.\n  * `:execute` - capabilities to execute query.","ref":"EdgeDB.Protocol.Enums.html#t:capability/0"},{"type":"type","title":"EdgeDB.Protocol.Enums.cardinality/0","doc":"Cardinality of the query result.\n\nValues:\n\n  * `:no_result` - query doesn't return anything.\n  * `:at_most_one` - query return an optional single elements.\n  * `:one` - query return a single element.\n  * `:many` - query return a set of elements.\n  * `:at_least_one` - query return a set with at least of one elements.","ref":"EdgeDB.Protocol.Enums.html#t:cardinality/0"},{"type":"type","title":"EdgeDB.Protocol.Enums.compilation_flag/0","doc":"Compilation flags for query to extend it's features.\n\nValues:\n\n  * `:inject_output_type_ids` - inject `__tid__` property as `.__type__.id` alias into returned objects.\n  * `:inject_output_type_names` - inject `__tname__` property as `.__type__.name` alias into returned objects.\n  * `:inject_output_object_ids` - inject `id` property into returned objects.","ref":"EdgeDB.Protocol.Enums.html#t:compilation_flag/0"},{"type":"type","title":"EdgeDB.Protocol.Enums.compilation_flags/0","doc":"Compilation flags for query to extend it's features.","ref":"EdgeDB.Protocol.Enums.html#t:compilation_flags/0"},{"type":"type","title":"EdgeDB.Protocol.Enums.output_format/0","doc":"Data output format.\n\nValues:\n\n  * `:binary` - return data encoded in binary.\n  * `:json` - return data as single row and single field that contains\n    the result set as a single JSON array.\n  * `:json_elements` - return a single JSON string per top-level set element.\n    This can be used to iterate over a large result set efficiently.\n  * `:none` - prevent EdgeDB from returning anything event if EdgeQL query does it.","ref":"EdgeDB.Protocol.Enums.html#t:output_format/0"},{"type":"module","title":"EdgeDB.AccessError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.AccessError` type.","ref":"EdgeDB.AccessError.html"},{"type":"function","title":"EdgeDB.AccessError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AccessError` type.","ref":"EdgeDB.AccessError.html#new/2"},{"type":"module","title":"EdgeDB.AccessPolicyError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.AccessPolicyError` type.","ref":"EdgeDB.AccessPolicyError.html"},{"type":"function","title":"EdgeDB.AccessPolicyError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AccessPolicyError` type.","ref":"EdgeDB.AccessPolicyError.html#new/2"},{"type":"module","title":"EdgeDB.AuthenticationError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.AuthenticationError` type.","ref":"EdgeDB.AuthenticationError.html"},{"type":"function","title":"EdgeDB.AuthenticationError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AuthenticationError` type.","ref":"EdgeDB.AuthenticationError.html#new/2"},{"type":"module","title":"EdgeDB.AvailabilityError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.AvailabilityError` type.","ref":"EdgeDB.AvailabilityError.html"},{"type":"function","title":"EdgeDB.AvailabilityError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AvailabilityError` type.","ref":"EdgeDB.AvailabilityError.html#new/2"},{"type":"module","title":"EdgeDB.BackendError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.BackendError` type.","ref":"EdgeDB.BackendError.html"},{"type":"function","title":"EdgeDB.BackendError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BackendError` type.","ref":"EdgeDB.BackendError.html#new/2"},{"type":"module","title":"EdgeDB.BackendUnavailableError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.BackendUnavailableError` type.","ref":"EdgeDB.BackendUnavailableError.html"},{"type":"function","title":"EdgeDB.BackendUnavailableError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BackendUnavailableError` type.","ref":"EdgeDB.BackendUnavailableError.html#new/2"},{"type":"module","title":"EdgeDB.BinaryProtocolError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.BinaryProtocolError` type.","ref":"EdgeDB.BinaryProtocolError.html"},{"type":"function","title":"EdgeDB.BinaryProtocolError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BinaryProtocolError` type.","ref":"EdgeDB.BinaryProtocolError.html#new/2"},{"type":"module","title":"EdgeDB.CapabilityError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.CapabilityError` type.","ref":"EdgeDB.CapabilityError.html"},{"type":"function","title":"EdgeDB.CapabilityError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.CapabilityError` type.","ref":"EdgeDB.CapabilityError.html#new/2"},{"type":"module","title":"EdgeDB.CardinalityViolationError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.CardinalityViolationError` type.","ref":"EdgeDB.CardinalityViolationError.html"},{"type":"function","title":"EdgeDB.CardinalityViolationError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.CardinalityViolationError` type.","ref":"EdgeDB.CardinalityViolationError.html#new/2"},{"type":"module","title":"EdgeDB.ClientConnectionClosedError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientConnectionClosedError` type.","ref":"EdgeDB.ClientConnectionClosedError.html"},{"type":"function","title":"EdgeDB.ClientConnectionClosedError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionClosedError` type.","ref":"EdgeDB.ClientConnectionClosedError.html#new/2"},{"type":"module","title":"EdgeDB.ClientConnectionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientConnectionError` type.","ref":"EdgeDB.ClientConnectionError.html"},{"type":"function","title":"EdgeDB.ClientConnectionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionError` type.","ref":"EdgeDB.ClientConnectionError.html#new/2"},{"type":"module","title":"EdgeDB.ClientConnectionFailedError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientConnectionFailedError` type.","ref":"EdgeDB.ClientConnectionFailedError.html"},{"type":"function","title":"EdgeDB.ClientConnectionFailedError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionFailedError` type.","ref":"EdgeDB.ClientConnectionFailedError.html#new/2"},{"type":"module","title":"EdgeDB.ClientConnectionFailedTemporarilyError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientConnectionFailedTemporarilyError` type.","ref":"EdgeDB.ClientConnectionFailedTemporarilyError.html"},{"type":"function","title":"EdgeDB.ClientConnectionFailedTemporarilyError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionFailedTemporarilyError` type.","ref":"EdgeDB.ClientConnectionFailedTemporarilyError.html#new/2"},{"type":"module","title":"EdgeDB.ClientConnectionTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientConnectionTimeoutError` type.","ref":"EdgeDB.ClientConnectionTimeoutError.html"},{"type":"function","title":"EdgeDB.ClientConnectionTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionTimeoutError` type.","ref":"EdgeDB.ClientConnectionTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.ClientError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ClientError` type.","ref":"EdgeDB.ClientError.html"},{"type":"function","title":"EdgeDB.ClientError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientError` type.","ref":"EdgeDB.ClientError.html#new/2"},{"type":"module","title":"EdgeDB.ConfigurationError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ConfigurationError` type.","ref":"EdgeDB.ConfigurationError.html"},{"type":"function","title":"EdgeDB.ConfigurationError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ConfigurationError` type.","ref":"EdgeDB.ConfigurationError.html#new/2"},{"type":"module","title":"EdgeDB.ConstraintViolationError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ConstraintViolationError` type.","ref":"EdgeDB.ConstraintViolationError.html"},{"type":"function","title":"EdgeDB.ConstraintViolationError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ConstraintViolationError` type.","ref":"EdgeDB.ConstraintViolationError.html#new/2"},{"type":"module","title":"EdgeDB.DisabledCapabilityError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DisabledCapabilityError` type.","ref":"EdgeDB.DisabledCapabilityError.html"},{"type":"function","title":"EdgeDB.DisabledCapabilityError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DisabledCapabilityError` type.","ref":"EdgeDB.DisabledCapabilityError.html#new/2"},{"type":"module","title":"EdgeDB.DivisionByZeroError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DivisionByZeroError` type.","ref":"EdgeDB.DivisionByZeroError.html"},{"type":"function","title":"EdgeDB.DivisionByZeroError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DivisionByZeroError` type.","ref":"EdgeDB.DivisionByZeroError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateCastDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateCastDefinitionError` type.","ref":"EdgeDB.DuplicateCastDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateCastDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateCastDefinitionError` type.","ref":"EdgeDB.DuplicateCastDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateConstraintDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateConstraintDefinitionError` type.","ref":"EdgeDB.DuplicateConstraintDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateConstraintDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateConstraintDefinitionError` type.","ref":"EdgeDB.DuplicateConstraintDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateDatabaseDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateDatabaseDefinitionError` type.","ref":"EdgeDB.DuplicateDatabaseDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateDatabaseDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateDatabaseDefinitionError` type.","ref":"EdgeDB.DuplicateDatabaseDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateDefinitionError` type.","ref":"EdgeDB.DuplicateDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateDefinitionError` type.","ref":"EdgeDB.DuplicateDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateFunctionDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateFunctionDefinitionError` type.","ref":"EdgeDB.DuplicateFunctionDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateFunctionDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateFunctionDefinitionError` type.","ref":"EdgeDB.DuplicateFunctionDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateLinkDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateLinkDefinitionError` type.","ref":"EdgeDB.DuplicateLinkDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateLinkDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateLinkDefinitionError` type.","ref":"EdgeDB.DuplicateLinkDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateModuleDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateModuleDefinitionError` type.","ref":"EdgeDB.DuplicateModuleDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateModuleDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateModuleDefinitionError` type.","ref":"EdgeDB.DuplicateModuleDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateOperatorDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateOperatorDefinitionError` type.","ref":"EdgeDB.DuplicateOperatorDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateOperatorDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateOperatorDefinitionError` type.","ref":"EdgeDB.DuplicateOperatorDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicatePropertyDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicatePropertyDefinitionError` type.","ref":"EdgeDB.DuplicatePropertyDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicatePropertyDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicatePropertyDefinitionError` type.","ref":"EdgeDB.DuplicatePropertyDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateUserDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateUserDefinitionError` type.","ref":"EdgeDB.DuplicateUserDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateUserDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateUserDefinitionError` type.","ref":"EdgeDB.DuplicateUserDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.DuplicateViewDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.DuplicateViewDefinitionError` type.","ref":"EdgeDB.DuplicateViewDefinitionError.html"},{"type":"function","title":"EdgeDB.DuplicateViewDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateViewDefinitionError` type.","ref":"EdgeDB.DuplicateViewDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.EdgeQLSyntaxError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.EdgeQLSyntaxError` type.","ref":"EdgeDB.EdgeQLSyntaxError.html"},{"type":"function","title":"EdgeDB.EdgeQLSyntaxError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.EdgeQLSyntaxError` type.","ref":"EdgeDB.EdgeQLSyntaxError.html#new/2"},{"type":"module","title":"EdgeDB.ExecutionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ExecutionError` type.","ref":"EdgeDB.ExecutionError.html"},{"type":"function","title":"EdgeDB.ExecutionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ExecutionError` type.","ref":"EdgeDB.ExecutionError.html#new/2"},{"type":"module","title":"EdgeDB.GraphQLSyntaxError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.GraphQLSyntaxError` type.","ref":"EdgeDB.GraphQLSyntaxError.html"},{"type":"function","title":"EdgeDB.GraphQLSyntaxError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.GraphQLSyntaxError` type.","ref":"EdgeDB.GraphQLSyntaxError.html#new/2"},{"type":"module","title":"EdgeDB.IdleSessionTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.IdleSessionTimeoutError` type.","ref":"EdgeDB.IdleSessionTimeoutError.html"},{"type":"function","title":"EdgeDB.IdleSessionTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IdleSessionTimeoutError` type.","ref":"EdgeDB.IdleSessionTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.IdleTransactionTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.IdleTransactionTimeoutError` type.","ref":"EdgeDB.IdleTransactionTimeoutError.html"},{"type":"function","title":"EdgeDB.IdleTransactionTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IdleTransactionTimeoutError` type.","ref":"EdgeDB.IdleTransactionTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.InputDataError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InputDataError` type.","ref":"EdgeDB.InputDataError.html"},{"type":"function","title":"EdgeDB.InputDataError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InputDataError` type.","ref":"EdgeDB.InputDataError.html#new/2"},{"type":"module","title":"EdgeDB.IntegrityError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.IntegrityError` type.","ref":"EdgeDB.IntegrityError.html"},{"type":"function","title":"EdgeDB.IntegrityError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IntegrityError` type.","ref":"EdgeDB.IntegrityError.html#new/2"},{"type":"module","title":"EdgeDB.InterfaceError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InterfaceError` type.","ref":"EdgeDB.InterfaceError.html"},{"type":"function","title":"EdgeDB.InterfaceError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InterfaceError` type.","ref":"EdgeDB.InterfaceError.html#new/2"},{"type":"module","title":"EdgeDB.InternalClientError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InternalClientError` type.","ref":"EdgeDB.InternalClientError.html"},{"type":"function","title":"EdgeDB.InternalClientError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InternalClientError` type.","ref":"EdgeDB.InternalClientError.html#new/2"},{"type":"module","title":"EdgeDB.InternalServerError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InternalServerError` type.","ref":"EdgeDB.InternalServerError.html"},{"type":"function","title":"EdgeDB.InternalServerError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InternalServerError` type.","ref":"EdgeDB.InternalServerError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidAliasDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidAliasDefinitionError` type.","ref":"EdgeDB.InvalidAliasDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidAliasDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidAliasDefinitionError` type.","ref":"EdgeDB.InvalidAliasDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidArgumentError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidArgumentError` type.","ref":"EdgeDB.InvalidArgumentError.html"},{"type":"function","title":"EdgeDB.InvalidArgumentError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidArgumentError` type.","ref":"EdgeDB.InvalidArgumentError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidCastDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidCastDefinitionError` type.","ref":"EdgeDB.InvalidCastDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidCastDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidCastDefinitionError` type.","ref":"EdgeDB.InvalidCastDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidConstraintDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidConstraintDefinitionError` type.","ref":"EdgeDB.InvalidConstraintDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidConstraintDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidConstraintDefinitionError` type.","ref":"EdgeDB.InvalidConstraintDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidDatabaseDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidDatabaseDefinitionError` type.","ref":"EdgeDB.InvalidDatabaseDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidDatabaseDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidDatabaseDefinitionError` type.","ref":"EdgeDB.InvalidDatabaseDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidDefinitionError` type.","ref":"EdgeDB.InvalidDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidDefinitionError` type.","ref":"EdgeDB.InvalidDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidFunctionDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidFunctionDefinitionError` type.","ref":"EdgeDB.InvalidFunctionDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidFunctionDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidFunctionDefinitionError` type.","ref":"EdgeDB.InvalidFunctionDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidLinkDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidLinkDefinitionError` type.","ref":"EdgeDB.InvalidLinkDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidLinkDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidLinkDefinitionError` type.","ref":"EdgeDB.InvalidLinkDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidLinkTargetError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidLinkTargetError` type.","ref":"EdgeDB.InvalidLinkTargetError.html"},{"type":"function","title":"EdgeDB.InvalidLinkTargetError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidLinkTargetError` type.","ref":"EdgeDB.InvalidLinkTargetError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidModuleDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidModuleDefinitionError` type.","ref":"EdgeDB.InvalidModuleDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidModuleDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidModuleDefinitionError` type.","ref":"EdgeDB.InvalidModuleDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidOperatorDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidOperatorDefinitionError` type.","ref":"EdgeDB.InvalidOperatorDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidOperatorDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidOperatorDefinitionError` type.","ref":"EdgeDB.InvalidOperatorDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidPropertyDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidPropertyDefinitionError` type.","ref":"EdgeDB.InvalidPropertyDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidPropertyDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidPropertyDefinitionError` type.","ref":"EdgeDB.InvalidPropertyDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidPropertyTargetError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidPropertyTargetError` type.","ref":"EdgeDB.InvalidPropertyTargetError.html"},{"type":"function","title":"EdgeDB.InvalidPropertyTargetError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidPropertyTargetError` type.","ref":"EdgeDB.InvalidPropertyTargetError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidReferenceError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidReferenceError` type.","ref":"EdgeDB.InvalidReferenceError.html"},{"type":"function","title":"EdgeDB.InvalidReferenceError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidReferenceError` type.","ref":"EdgeDB.InvalidReferenceError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidSyntaxError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidSyntaxError` type.","ref":"EdgeDB.InvalidSyntaxError.html"},{"type":"function","title":"EdgeDB.InvalidSyntaxError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidSyntaxError` type.","ref":"EdgeDB.InvalidSyntaxError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidTargetError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidTargetError` type.","ref":"EdgeDB.InvalidTargetError.html"},{"type":"function","title":"EdgeDB.InvalidTargetError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidTargetError` type.","ref":"EdgeDB.InvalidTargetError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidTypeError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidTypeError` type.","ref":"EdgeDB.InvalidTypeError.html"},{"type":"function","title":"EdgeDB.InvalidTypeError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidTypeError` type.","ref":"EdgeDB.InvalidTypeError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidUserDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidUserDefinitionError` type.","ref":"EdgeDB.InvalidUserDefinitionError.html"},{"type":"function","title":"EdgeDB.InvalidUserDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidUserDefinitionError` type.","ref":"EdgeDB.InvalidUserDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.InvalidValueError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.InvalidValueError` type.","ref":"EdgeDB.InvalidValueError.html"},{"type":"function","title":"EdgeDB.InvalidValueError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidValueError` type.","ref":"EdgeDB.InvalidValueError.html#new/2"},{"type":"module","title":"EdgeDB.LogMessage","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.LogMessage` type.","ref":"EdgeDB.LogMessage.html"},{"type":"function","title":"EdgeDB.LogMessage.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.LogMessage` type.","ref":"EdgeDB.LogMessage.html#new/2"},{"type":"module","title":"EdgeDB.MissingArgumentError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.MissingArgumentError` type.","ref":"EdgeDB.MissingArgumentError.html"},{"type":"function","title":"EdgeDB.MissingArgumentError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.MissingArgumentError` type.","ref":"EdgeDB.MissingArgumentError.html#new/2"},{"type":"module","title":"EdgeDB.MissingRequiredError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.MissingRequiredError` type.","ref":"EdgeDB.MissingRequiredError.html"},{"type":"function","title":"EdgeDB.MissingRequiredError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.MissingRequiredError` type.","ref":"EdgeDB.MissingRequiredError.html#new/2"},{"type":"module","title":"EdgeDB.NoDataError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.NoDataError` type.","ref":"EdgeDB.NoDataError.html"},{"type":"function","title":"EdgeDB.NoDataError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.NoDataError` type.","ref":"EdgeDB.NoDataError.html#new/2"},{"type":"module","title":"EdgeDB.NumericOutOfRangeError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.NumericOutOfRangeError` type.","ref":"EdgeDB.NumericOutOfRangeError.html"},{"type":"function","title":"EdgeDB.NumericOutOfRangeError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.NumericOutOfRangeError` type.","ref":"EdgeDB.NumericOutOfRangeError.html#new/2"},{"type":"module","title":"EdgeDB.ParameterTypeMismatchError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ParameterTypeMismatchError` type.","ref":"EdgeDB.ParameterTypeMismatchError.html"},{"type":"function","title":"EdgeDB.ParameterTypeMismatchError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ParameterTypeMismatchError` type.","ref":"EdgeDB.ParameterTypeMismatchError.html#new/2"},{"type":"module","title":"EdgeDB.ProtocolError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ProtocolError` type.","ref":"EdgeDB.ProtocolError.html"},{"type":"function","title":"EdgeDB.ProtocolError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ProtocolError` type.","ref":"EdgeDB.ProtocolError.html#new/2"},{"type":"module","title":"EdgeDB.QueryArgumentError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.QueryArgumentError` type.","ref":"EdgeDB.QueryArgumentError.html"},{"type":"function","title":"EdgeDB.QueryArgumentError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryArgumentError` type.","ref":"EdgeDB.QueryArgumentError.html#new/2"},{"type":"module","title":"EdgeDB.QueryError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.QueryError` type.","ref":"EdgeDB.QueryError.html"},{"type":"function","title":"EdgeDB.QueryError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryError` type.","ref":"EdgeDB.QueryError.html#new/2"},{"type":"module","title":"EdgeDB.QueryTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.QueryTimeoutError` type.","ref":"EdgeDB.QueryTimeoutError.html"},{"type":"function","title":"EdgeDB.QueryTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryTimeoutError` type.","ref":"EdgeDB.QueryTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.ResultCardinalityMismatchError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.ResultCardinalityMismatchError` type.","ref":"EdgeDB.ResultCardinalityMismatchError.html"},{"type":"function","title":"EdgeDB.ResultCardinalityMismatchError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ResultCardinalityMismatchError` type.","ref":"EdgeDB.ResultCardinalityMismatchError.html#new/2"},{"type":"module","title":"EdgeDB.SchemaDefinitionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.SchemaDefinitionError` type.","ref":"EdgeDB.SchemaDefinitionError.html"},{"type":"function","title":"EdgeDB.SchemaDefinitionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaDefinitionError` type.","ref":"EdgeDB.SchemaDefinitionError.html#new/2"},{"type":"module","title":"EdgeDB.SchemaError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.SchemaError` type.","ref":"EdgeDB.SchemaError.html"},{"type":"function","title":"EdgeDB.SchemaError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaError` type.","ref":"EdgeDB.SchemaError.html#new/2"},{"type":"module","title":"EdgeDB.SchemaSyntaxError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.SchemaSyntaxError` type.","ref":"EdgeDB.SchemaSyntaxError.html"},{"type":"function","title":"EdgeDB.SchemaSyntaxError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaSyntaxError` type.","ref":"EdgeDB.SchemaSyntaxError.html#new/2"},{"type":"module","title":"EdgeDB.SessionTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.SessionTimeoutError` type.","ref":"EdgeDB.SessionTimeoutError.html"},{"type":"function","title":"EdgeDB.SessionTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SessionTimeoutError` type.","ref":"EdgeDB.SessionTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.StateMismatchError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.StateMismatchError` type.","ref":"EdgeDB.StateMismatchError.html"},{"type":"function","title":"EdgeDB.StateMismatchError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.StateMismatchError` type.","ref":"EdgeDB.StateMismatchError.html#new/2"},{"type":"module","title":"EdgeDB.TransactionConflictError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TransactionConflictError` type.","ref":"EdgeDB.TransactionConflictError.html"},{"type":"function","title":"EdgeDB.TransactionConflictError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionConflictError` type.","ref":"EdgeDB.TransactionConflictError.html#new/2"},{"type":"module","title":"EdgeDB.TransactionDeadlockError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TransactionDeadlockError` type.","ref":"EdgeDB.TransactionDeadlockError.html"},{"type":"function","title":"EdgeDB.TransactionDeadlockError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionDeadlockError` type.","ref":"EdgeDB.TransactionDeadlockError.html#new/2"},{"type":"module","title":"EdgeDB.TransactionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TransactionError` type.","ref":"EdgeDB.TransactionError.html"},{"type":"function","title":"EdgeDB.TransactionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionError` type.","ref":"EdgeDB.TransactionError.html#new/2"},{"type":"module","title":"EdgeDB.TransactionSerializationError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TransactionSerializationError` type.","ref":"EdgeDB.TransactionSerializationError.html"},{"type":"function","title":"EdgeDB.TransactionSerializationError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionSerializationError` type.","ref":"EdgeDB.TransactionSerializationError.html#new/2"},{"type":"module","title":"EdgeDB.TransactionTimeoutError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TransactionTimeoutError` type.","ref":"EdgeDB.TransactionTimeoutError.html"},{"type":"function","title":"EdgeDB.TransactionTimeoutError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionTimeoutError` type.","ref":"EdgeDB.TransactionTimeoutError.html#new/2"},{"type":"module","title":"EdgeDB.TypeSpecNotFoundError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.TypeSpecNotFoundError` type.","ref":"EdgeDB.TypeSpecNotFoundError.html"},{"type":"function","title":"EdgeDB.TypeSpecNotFoundError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TypeSpecNotFoundError` type.","ref":"EdgeDB.TypeSpecNotFoundError.html#new/2"},{"type":"module","title":"EdgeDB.UnexpectedMessageError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnexpectedMessageError` type.","ref":"EdgeDB.UnexpectedMessageError.html"},{"type":"function","title":"EdgeDB.UnexpectedMessageError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnexpectedMessageError` type.","ref":"EdgeDB.UnexpectedMessageError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownArgumentError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownArgumentError` type.","ref":"EdgeDB.UnknownArgumentError.html"},{"type":"function","title":"EdgeDB.UnknownArgumentError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownArgumentError` type.","ref":"EdgeDB.UnknownArgumentError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownDatabaseError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownDatabaseError` type.","ref":"EdgeDB.UnknownDatabaseError.html"},{"type":"function","title":"EdgeDB.UnknownDatabaseError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownDatabaseError` type.","ref":"EdgeDB.UnknownDatabaseError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownLinkError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownLinkError` type.","ref":"EdgeDB.UnknownLinkError.html"},{"type":"function","title":"EdgeDB.UnknownLinkError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownLinkError` type.","ref":"EdgeDB.UnknownLinkError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownModuleError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownModuleError` type.","ref":"EdgeDB.UnknownModuleError.html"},{"type":"function","title":"EdgeDB.UnknownModuleError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownModuleError` type.","ref":"EdgeDB.UnknownModuleError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownParameterError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownParameterError` type.","ref":"EdgeDB.UnknownParameterError.html"},{"type":"function","title":"EdgeDB.UnknownParameterError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownParameterError` type.","ref":"EdgeDB.UnknownParameterError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownPropertyError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownPropertyError` type.","ref":"EdgeDB.UnknownPropertyError.html"},{"type":"function","title":"EdgeDB.UnknownPropertyError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownPropertyError` type.","ref":"EdgeDB.UnknownPropertyError.html#new/2"},{"type":"module","title":"EdgeDB.UnknownUserError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnknownUserError` type.","ref":"EdgeDB.UnknownUserError.html"},{"type":"function","title":"EdgeDB.UnknownUserError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownUserError` type.","ref":"EdgeDB.UnknownUserError.html#new/2"},{"type":"module","title":"EdgeDB.UnsupportedBackendFeatureError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnsupportedBackendFeatureError` type.","ref":"EdgeDB.UnsupportedBackendFeatureError.html"},{"type":"function","title":"EdgeDB.UnsupportedBackendFeatureError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedBackendFeatureError` type.","ref":"EdgeDB.UnsupportedBackendFeatureError.html#new/2"},{"type":"module","title":"EdgeDB.UnsupportedCapabilityError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnsupportedCapabilityError` type.","ref":"EdgeDB.UnsupportedCapabilityError.html"},{"type":"function","title":"EdgeDB.UnsupportedCapabilityError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedCapabilityError` type.","ref":"EdgeDB.UnsupportedCapabilityError.html#new/2"},{"type":"module","title":"EdgeDB.UnsupportedFeatureError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnsupportedFeatureError` type.","ref":"EdgeDB.UnsupportedFeatureError.html"},{"type":"function","title":"EdgeDB.UnsupportedFeatureError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedFeatureError` type.","ref":"EdgeDB.UnsupportedFeatureError.html#new/2"},{"type":"module","title":"EdgeDB.UnsupportedProtocolVersionError","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.UnsupportedProtocolVersionError` type.","ref":"EdgeDB.UnsupportedProtocolVersionError.html"},{"type":"function","title":"EdgeDB.UnsupportedProtocolVersionError.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedProtocolVersionError` type.","ref":"EdgeDB.UnsupportedProtocolVersionError.html#new/2"},{"type":"module","title":"EdgeDB.WarningMessage","doc":"A shorthand module to create `EdgeDB.Error` of `EdgeDB.WarningMessage` type.","ref":"EdgeDB.WarningMessage.html"},{"type":"function","title":"EdgeDB.WarningMessage.new/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.WarningMessage` type.","ref":"EdgeDB.WarningMessage.html#new/2"},{"type":"exception","title":"EdgeDB.Error","doc":"Exception returned by the client if an error occurred.\n\nMost of the functions in the `EdgeDB.Error` module are a shorthands for simplifying `EdgeDB.Error` exception\n  constructing. These functions are generated at compile time from a copy of the\n  [errors.txt](https://github.com/edgedb/edgedb/blob/a529aae753319f26cce942ae4fc7512dd0c5a37b/edb/api/errors.txt) file.\n\nThe useful ones are:\n\n  * `EdgeDB.Error.retry?/1`\n  * `EdgeDB.Error.inheritor?/2`\n\nBy default the client generates exception messages in full format, attempting to output all useful\n  information about the error location if it is possible.\n\nThis behavior can be disabled by using the `:render_error_hints` configuration of the `:edgedb` application.\n\nThe renderer also tries to colorize the output message. This behavior defaults to `IO.ANSI.enabled?/0`,\n  but can also be configured with the `:rended_colored_errors` setting for the `:edgedb` application.","ref":"EdgeDB.Error.html"},{"type":"function","title":"EdgeDB.Error.access_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AccessError` type.","ref":"EdgeDB.Error.html#access_error/2"},{"type":"function","title":"EdgeDB.Error.access_policy_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AccessPolicyError` type.","ref":"EdgeDB.Error.html#access_policy_error/2"},{"type":"function","title":"EdgeDB.Error.authentication_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AuthenticationError` type.","ref":"EdgeDB.Error.html#authentication_error/2"},{"type":"function","title":"EdgeDB.Error.availability_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.AvailabilityError` type.","ref":"EdgeDB.Error.html#availability_error/2"},{"type":"function","title":"EdgeDB.Error.backend_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BackendError` type.","ref":"EdgeDB.Error.html#backend_error/2"},{"type":"function","title":"EdgeDB.Error.backend_unavailable_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BackendUnavailableError` type.","ref":"EdgeDB.Error.html#backend_unavailable_error/2"},{"type":"function","title":"EdgeDB.Error.binary_protocol_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.BinaryProtocolError` type.","ref":"EdgeDB.Error.html#binary_protocol_error/2"},{"type":"function","title":"EdgeDB.Error.capability_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.CapabilityError` type.","ref":"EdgeDB.Error.html#capability_error/2"},{"type":"function","title":"EdgeDB.Error.cardinality_violation_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.CardinalityViolationError` type.","ref":"EdgeDB.Error.html#cardinality_violation_error/2"},{"type":"function","title":"EdgeDB.Error.client_connection_closed_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionClosedError` type.","ref":"EdgeDB.Error.html#client_connection_closed_error/2"},{"type":"function","title":"EdgeDB.Error.client_connection_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionError` type.","ref":"EdgeDB.Error.html#client_connection_error/2"},{"type":"function","title":"EdgeDB.Error.client_connection_failed_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionFailedError` type.","ref":"EdgeDB.Error.html#client_connection_failed_error/2"},{"type":"function","title":"EdgeDB.Error.client_connection_failed_temporarily_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionFailedTemporarilyError` type.","ref":"EdgeDB.Error.html#client_connection_failed_temporarily_error/2"},{"type":"function","title":"EdgeDB.Error.client_connection_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientConnectionTimeoutError` type.","ref":"EdgeDB.Error.html#client_connection_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.client_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ClientError` type.","ref":"EdgeDB.Error.html#client_error/2"},{"type":"function","title":"EdgeDB.Error.configuration_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ConfigurationError` type.","ref":"EdgeDB.Error.html#configuration_error/2"},{"type":"function","title":"EdgeDB.Error.constraint_violation_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ConstraintViolationError` type.","ref":"EdgeDB.Error.html#constraint_violation_error/2"},{"type":"function","title":"EdgeDB.Error.disabled_capability_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DisabledCapabilityError` type.","ref":"EdgeDB.Error.html#disabled_capability_error/2"},{"type":"function","title":"EdgeDB.Error.division_by_zero_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DivisionByZeroError` type.","ref":"EdgeDB.Error.html#division_by_zero_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_cast_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateCastDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_cast_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_constraint_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateConstraintDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_constraint_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_database_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateDatabaseDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_database_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_function_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateFunctionDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_function_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_link_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateLinkDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_link_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_module_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateModuleDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_module_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_operator_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateOperatorDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_operator_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_property_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicatePropertyDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_property_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_user_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateUserDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_user_definition_error/2"},{"type":"function","title":"EdgeDB.Error.duplicate_view_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.DuplicateViewDefinitionError` type.","ref":"EdgeDB.Error.html#duplicate_view_definition_error/2"},{"type":"function","title":"EdgeDB.Error.edge_ql_syntax_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.EdgeQLSyntaxError` type.","ref":"EdgeDB.Error.html#edge_ql_syntax_error/2"},{"type":"function","title":"EdgeDB.Error.execution_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ExecutionError` type.","ref":"EdgeDB.Error.html#execution_error/2"},{"type":"function","title":"EdgeDB.Error.graph_ql_syntax_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.GraphQLSyntaxError` type.","ref":"EdgeDB.Error.html#graph_ql_syntax_error/2"},{"type":"function","title":"EdgeDB.Error.idle_session_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IdleSessionTimeoutError` type.","ref":"EdgeDB.Error.html#idle_session_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.idle_transaction_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IdleTransactionTimeoutError` type.","ref":"EdgeDB.Error.html#idle_transaction_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.inheritor?/2","doc":"Check if the exception is an inheritor of another EdgeDB error.","ref":"EdgeDB.Error.html#inheritor?/2"},{"type":"function","title":"EdgeDB.Error.input_data_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InputDataError` type.","ref":"EdgeDB.Error.html#input_data_error/2"},{"type":"function","title":"EdgeDB.Error.integrity_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.IntegrityError` type.","ref":"EdgeDB.Error.html#integrity_error/2"},{"type":"function","title":"EdgeDB.Error.interface_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InterfaceError` type.","ref":"EdgeDB.Error.html#interface_error/2"},{"type":"function","title":"EdgeDB.Error.internal_client_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InternalClientError` type.","ref":"EdgeDB.Error.html#internal_client_error/2"},{"type":"function","title":"EdgeDB.Error.internal_server_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InternalServerError` type.","ref":"EdgeDB.Error.html#internal_server_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_alias_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidAliasDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_alias_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_argument_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidArgumentError` type.","ref":"EdgeDB.Error.html#invalid_argument_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_cast_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidCastDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_cast_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_constraint_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidConstraintDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_constraint_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_database_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidDatabaseDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_database_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_function_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidFunctionDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_function_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_link_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidLinkDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_link_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_link_target_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidLinkTargetError` type.","ref":"EdgeDB.Error.html#invalid_link_target_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_module_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidModuleDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_module_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_operator_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidOperatorDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_operator_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_property_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidPropertyDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_property_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_property_target_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidPropertyTargetError` type.","ref":"EdgeDB.Error.html#invalid_property_target_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_reference_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidReferenceError` type.","ref":"EdgeDB.Error.html#invalid_reference_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_syntax_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidSyntaxError` type.","ref":"EdgeDB.Error.html#invalid_syntax_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_target_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidTargetError` type.","ref":"EdgeDB.Error.html#invalid_target_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_type_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidTypeError` type.","ref":"EdgeDB.Error.html#invalid_type_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_user_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidUserDefinitionError` type.","ref":"EdgeDB.Error.html#invalid_user_definition_error/2"},{"type":"function","title":"EdgeDB.Error.invalid_value_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.InvalidValueError` type.","ref":"EdgeDB.Error.html#invalid_value_error/2"},{"type":"function","title":"EdgeDB.Error.log_message/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.LogMessage` type.","ref":"EdgeDB.Error.html#log_message/2"},{"type":"function","title":"EdgeDB.Error.missing_argument_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.MissingArgumentError` type.","ref":"EdgeDB.Error.html#missing_argument_error/2"},{"type":"function","title":"EdgeDB.Error.missing_required_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.MissingRequiredError` type.","ref":"EdgeDB.Error.html#missing_required_error/2"},{"type":"function","title":"EdgeDB.Error.no_data_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.NoDataError` type.","ref":"EdgeDB.Error.html#no_data_error/2"},{"type":"function","title":"EdgeDB.Error.numeric_out_of_range_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.NumericOutOfRangeError` type.","ref":"EdgeDB.Error.html#numeric_out_of_range_error/2"},{"type":"function","title":"EdgeDB.Error.parameter_type_mismatch_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ParameterTypeMismatchError` type.","ref":"EdgeDB.Error.html#parameter_type_mismatch_error/2"},{"type":"function","title":"EdgeDB.Error.protocol_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ProtocolError` type.","ref":"EdgeDB.Error.html#protocol_error/2"},{"type":"function","title":"EdgeDB.Error.query_argument_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryArgumentError` type.","ref":"EdgeDB.Error.html#query_argument_error/2"},{"type":"function","title":"EdgeDB.Error.query_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryError` type.","ref":"EdgeDB.Error.html#query_error/2"},{"type":"function","title":"EdgeDB.Error.query_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.QueryTimeoutError` type.","ref":"EdgeDB.Error.html#query_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.reconnect?/1","doc":"Check if should try to reconnect to EdgeDB server.\n\n**NOTE**: this function is not used right now, because `DBConnection` reconnects it connection itself.","ref":"EdgeDB.Error.html#reconnect?/1"},{"type":"function","title":"EdgeDB.Error.result_cardinality_mismatch_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.ResultCardinalityMismatchError` type.","ref":"EdgeDB.Error.html#result_cardinality_mismatch_error/2"},{"type":"function","title":"EdgeDB.Error.retry?/1","doc":"Check if should try to repeat the query during the execution of which an error occurred.","ref":"EdgeDB.Error.html#retry?/1"},{"type":"function","title":"EdgeDB.Error.schema_definition_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaDefinitionError` type.","ref":"EdgeDB.Error.html#schema_definition_error/2"},{"type":"function","title":"EdgeDB.Error.schema_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaError` type.","ref":"EdgeDB.Error.html#schema_error/2"},{"type":"function","title":"EdgeDB.Error.schema_syntax_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SchemaSyntaxError` type.","ref":"EdgeDB.Error.html#schema_syntax_error/2"},{"type":"function","title":"EdgeDB.Error.session_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.SessionTimeoutError` type.","ref":"EdgeDB.Error.html#session_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.state_mismatch_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.StateMismatchError` type.","ref":"EdgeDB.Error.html#state_mismatch_error/2"},{"type":"function","title":"EdgeDB.Error.transaction_conflict_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionConflictError` type.","ref":"EdgeDB.Error.html#transaction_conflict_error/2"},{"type":"function","title":"EdgeDB.Error.transaction_deadlock_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionDeadlockError` type.","ref":"EdgeDB.Error.html#transaction_deadlock_error/2"},{"type":"function","title":"EdgeDB.Error.transaction_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionError` type.","ref":"EdgeDB.Error.html#transaction_error/2"},{"type":"function","title":"EdgeDB.Error.transaction_serialization_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionSerializationError` type.","ref":"EdgeDB.Error.html#transaction_serialization_error/2"},{"type":"function","title":"EdgeDB.Error.transaction_timeout_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TransactionTimeoutError` type.","ref":"EdgeDB.Error.html#transaction_timeout_error/2"},{"type":"function","title":"EdgeDB.Error.type_spec_not_found_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.TypeSpecNotFoundError` type.","ref":"EdgeDB.Error.html#type_spec_not_found_error/2"},{"type":"function","title":"EdgeDB.Error.unexpected_message_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnexpectedMessageError` type.","ref":"EdgeDB.Error.html#unexpected_message_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_argument_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownArgumentError` type.","ref":"EdgeDB.Error.html#unknown_argument_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_database_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownDatabaseError` type.","ref":"EdgeDB.Error.html#unknown_database_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_link_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownLinkError` type.","ref":"EdgeDB.Error.html#unknown_link_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_module_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownModuleError` type.","ref":"EdgeDB.Error.html#unknown_module_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_parameter_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownParameterError` type.","ref":"EdgeDB.Error.html#unknown_parameter_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_property_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownPropertyError` type.","ref":"EdgeDB.Error.html#unknown_property_error/2"},{"type":"function","title":"EdgeDB.Error.unknown_user_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnknownUserError` type.","ref":"EdgeDB.Error.html#unknown_user_error/2"},{"type":"function","title":"EdgeDB.Error.unsupported_backend_feature_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedBackendFeatureError` type.","ref":"EdgeDB.Error.html#unsupported_backend_feature_error/2"},{"type":"function","title":"EdgeDB.Error.unsupported_capability_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedCapabilityError` type.","ref":"EdgeDB.Error.html#unsupported_capability_error/2"},{"type":"function","title":"EdgeDB.Error.unsupported_feature_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedFeatureError` type.","ref":"EdgeDB.Error.html#unsupported_feature_error/2"},{"type":"function","title":"EdgeDB.Error.unsupported_protocol_version_error/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.UnsupportedProtocolVersionError` type.","ref":"EdgeDB.Error.html#unsupported_protocol_version_error/2"},{"type":"function","title":"EdgeDB.Error.warning_message/2","doc":"Create a new `EdgeDB.Error` with `EdgeDB.WarningMessage` type.","ref":"EdgeDB.Error.html#warning_message/2"},{"type":"type","title":"EdgeDB.Error.t/0","doc":"Exception returned by the client if an error occurred.\n\nFields:\n\n  * `:message` - human-readable error message.\n  * `:type` - alias module for EdgeDB error.\n  * `:name` - error name from EdgeDB.\n  * `:code` - internal error code.","ref":"EdgeDB.Error.html#t:t/0"},{"type":"extras","title":"EdgeDB client for Elixir","doc":"# EdgeDB client for Elixir\n\n`edgedb-elixir` is the [EdgeDB](https://edgedb.com) client for Elixir. The documentation for client\n  is available on [edgedb.com](https://www.edgedb.com/docs/clients/elixir) and on\n  [hex.pm](https://hexdocs.pm/edgedb).","ref":"main.html"},{"type":"extras","title":"Installation - EdgeDB client for Elixir","doc":"`edgedb-elixir` is available on [hex.pm](https://hex.pm/packages/edgedb) and can be installed via `mix`.\n  Just add `:edgedb` to your dependencies in the `mix.exs` file:\n\n```elixir\n{:edgedb, \"~> 0.1\"}\n```","ref":"main.html#installation"},{"type":"extras","title":"JSON support - EdgeDB client for Elixir","doc":"`EdgeDB` comes with JSON support out of the box via the `Jason` library.\n  To use it, add `:jason` to your dependencies in the `mix.exs` file:\n\n```elixir\n{:jason, \"~> 1.0\"}\n```\n\nThe JSON library can be configured using the `:json` option in the `:edgedb` application configuration:\n\n```elixir\nconfig :edgedb,\n    json: CustomJSONLibrary\n```\n\nThe JSON library is injected in the compiled `EdgeDB` code, so be sure to recompile `EdgeDB` if you change it:\n\n```bash\n$ mix deps.clean edgedb --build\n```","ref":"main.html#json-support"},{"type":"extras","title":"Timex support - EdgeDB client for Elixir","doc":"`EdgeDB` can work with `Timex` out of the box. If you define `Timex` as an application dependency,\n  `EdgeDB` will use `Timex.Duration` to encode and decode the `std::duration` type from database.\n  If you don't like this behavior, you can set `EdgeDB` to ignore `Timex` using\n  the `:timex_duration` option by setting this to false in the `:edgedb` application configuration:\n\n```elixir\nconfig :edgedb,\n    timex_duration: false\n```\n\n`EdgeDB` will inject the use of `Timex` into the `std::duration` codec at compile time,\n  so be sure to recompile `EdgeDB` if you change this behavior:\n\n```bash\n$ mix deps.clean edgedb --build\n```","ref":"main.html#timex-support"},{"type":"extras","title":"License - EdgeDB client for Elixir","doc":"This project is licensed under the terms of the Apache 2.0 license.\n  See [LICENSE](https://github.com/edgedb/edgedb-elixir/blob/master/LICENSE) for details.","ref":"main.html#license"},{"type":"extras","title":"Usage","doc":"# Usage\n\nThe basic user API for `edgedb-elixir` is provided by the `EdgeDB` module and in most cases you will use only it.\n  The exception is when you want to define custom codecs. Checkout the guide on\n  [hex.pm](https://hexdocs.pm/edgedb/custom-codecs.html) or on\n  [edgedb.com](https://www.edgedb.com/docs/clients/elixir/custom-codecs) for more information.\n\n`EdgeDB` provides several functions for querying data from the database, which are named in `EdgeDB.query*/4` format.\n  Transactions are supported with `EdgeDB.transaction/3` function.","ref":"usage.html"},{"type":"extras","title":"Establishing a connection - Usage","doc":"`edgedb-elixir`, like other EdgeDB clients, allows a very flexible way to define how to connect to an instance.\n  For more information, see `t:EdgeDB.connect_option/0`.\n\nThe examples on this page will involve connecting to an instance using\n  [edgedb projects](https://www.edgedb.com/docs/cli/edgedb_project/index#edgedb-project).\n  Run `edgedb project init` to initialize the project:\n\n```bash\n$ edgedb project init\n```","ref":"usage.html#establishing-a-connection"},{"type":"extras","title":"Database schema - Usage","doc":"Ensure that your database has the following schema:\n\n```sdl\nmodule default {\n    type User {\n        required name: str {\n            constraint exclusive;\n        };\n    }\n\n    type Post {\n        required body: str;\n\n        required author: User;\n        multi comments: Post;\n    }\n};\n```\n\nLet's fill the database with some data, which will be used in further examples:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> EdgeDB.query!(client, \"\"\"\n...(2)> WITH\n...(2)>     p1 := (\n...(2)>         insert Post {\n...(2)>             body := 'Yes!',\n...(2)>             author := (\n...(2)>                 insert User {\n...(2)>                     name := 'commentator1'\n...(2)>                 }\n...(2)>             )\n...(2)>         }\n...(2)>     ),\n...(2)>     p2 := (\n...(2)>         insert Post {\n...(2)>             body := 'Absolutely amazing',\n...(2)>             author := (\n...(2)>                 insert User {\n...(2)>                     name := 'commentator2'\n...(2)>                 }\n...(2)>             )\n...(2)>         }\n...(2)>     ),\n...(2)>     p3 := (\n...(2)>         insert Post {\n...(2)>             body := 'FYI here is a link to the Elixir client: https://hex.pm/packages/edgedb',\n...(2)>             author := (\n...(2)>                 insert User {\n...(2)>                     name := 'commentator3'\n...(2)>                 }\n...(2)>             )\n...(2)>         }\n...(2)>     )\n...(2)> insert Post {\n...(2)>     body := 'EdgeDB is awesome! Try the Elixir client for it',\n...(2)>     author := (\n...(2)>         insert User {\n...(2)>             name := 'author1'\n...(2)>         }\n...(2)>     ),\n...(2)>     comments := {p1, p2, p3}\n...(2)> }\n...(2)> \"\"\")\n```","ref":"usage.html#database-schema"},{"type":"extras","title":"Querying data from EdgeDB - Usage","doc":"Depending on the expected results of the query, you can use different functions to retrieve data from the database.\n  This is called the cardinality of the result and is better explained in\n  [the relevant documentation](https://www.edgedb.com/docs/reference/edgeql/cardinality#cardinality).","ref":"usage.html#querying-data-from-edgedb"},{"type":"extras","title":"Querying a set of elements - Usage","doc":"If you want to receive an `EdgeDB.Set` from your query, just use the `EdgeDB.query/4` or `EdgeDB.query!/4` functions.\n  The difference between the two functions is that `EdgeDB.query/4` will return an `:ok` tuple with result\n  if successful or a `:error`  tuple with `EdgeDB.Error` if an error occurred during the query execution.\n  `EdgeDB.query!/4` will return a plain result if successful or raise `EdgeDB.Error` if error.\n\nLet's query all existing posts with their bodies:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, posts} = EdgeDB.query(client, \"select Post { body }\")\n{:ok,\n #EdgeDB.Set<{#EdgeDB.Object ,\n  #EdgeDB.Object , #EdgeDB.Object ,\n  #EdgeDB.Object }>}\n```\n\nWe can iterate over `EdgeDB.Set` and inspect each object separately:\n\n```iex\niex(3)> Enum.each(posts, fn post ->\n...(3)>   IO.inspect(post[:body], label: \"post (#{inspect(post.id)})\")\n...(3)> end)\npost (\"3c5c8cf2-860f-11ec-a22a-2b0ab4e21d4b\"): \"EdgeDB is awesome! Try the Elixir client for it\"\npost (\"3c5c904e-860f-11ec-a22a-f7cdb9bcb510\"): \"Yes!\"\npost (\"3c5c9256-860f-11ec-a22a-0343fa0961f3\"): \"Absolutely amazing\"\npost (\"3c5c9378-860f-11ec-a22a-0713dfca8baa\"): \"FYI here is a link to the Elixir client: https://hex.pm/packages/edgedb\"\n:ok\n```","ref":"usage.html#querying-a-set-of-elements"},{"type":"extras","title":"Querying a single element - Usage","doc":"If you know that the query will return only one element or none, you can use `EdgeDB.query_single/4` and\n  `EdgeDB.query_single!/4` functions. This function will automatically unpack the underlying `EdgeDB.Set`\n  and return the requested item (or `nil` if the set is empty).\n\nLet's query a post with a link to the Elixir client for EdgeDB:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> post = EdgeDB.query_single!(client, \"select Post filter contains(.body, 'https://hex.pm/packages/edgedb') limit 1\")\niex(3)> post[:id]\n\"3c5c9378-860f-11ec-a22a-0713dfca8baa\"\n```\n\nIf we try to select a `Post` that does not exist, `nil` will be returned:\n\n```iex\niex(4)> EdgeDB.query_single!(client, \"select Post filter .body = 'lol' limit 1\")\nnil\n```","ref":"usage.html#querying-a-single-element"},{"type":"extras","title":"Querying a required single element - Usage","doc":"In case we want to ensure that the requested element must exist, we can use the functions `EdgeDB.query_required_single/4` and\n  `EdgeDB.query_required_single!/4`. Instead of returning `nil` they will return `EdgeDB.Error` in case of a missing element:\n\n```iex\niex(5)> EdgeDB.query_required_single!(client, \"select Post filter .body = 'lol' limit 1\")\n** (EdgeDB.Error) NoDataError: expected result, but query did not return any data\n```","ref":"usage.html#querying-a-required-single-element"},{"type":"extras","title":"Transactions - Usage","doc":"> #### NOTE {: .warning}\n>\n> Note that `EdgeDB.transaction/3` calls can not be nested.\n\nThe API for transactions is provided by the `EdgeDB.transaction/3` function:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link()\niex(2)> {:ok, user} =\n...(2)>  EdgeDB.transaction(client, fn conn ->\n...(2)>    EdgeDB.query_required_single!(conn, \"insert User { name :=  $username }\", username: \"user1\")\n...(2)>  end)\n```\n\nTransactions can be rollbacked using the `EdgeDB.rollback/2` function or automatically\n  if an error has occurred inside a transaction block:\n\n```iex\niex(3)> {:error, :rollback} =\n...(3)>  EdgeDB.transaction(client, fn conn ->\n...(3)>    EdgeDB.query_required_single!(conn, \"insert User { name :=  $username }\", username: \"wrong_username\")\n...(3)>    EdgeDB.rollback(conn)\n...(3)>  end)\niex(4)> EdgeDB.query_single!(client, \"select User { name } filter .name =  $username\", username: \"wrong_username\")\nnil\n```\n\nTransactions are retriable. This means that if certain types of errors occur when querying data from the database,\n  the transaction block can be automatically retried.\n\nThe following types of errors can be retried retried:\n\n  * `TransactionConflictError` and its inheritors.\n  * Network errors (e.g. a socket was closed).\n\nAs an example, let's create a transaction conflict to show how this works. In the first example, we will disable retries:\n\n```iex\niex(5)> callback = fn conn, body ->\n...(5)>  Process.sleep(500)\n...(5)>  EdgeDB.query!(conn, \"update Post filter .author.id =  $user_id set { body :=  $new_body }\", user_id: user.id, new_body: body)\n...(5)>  Process.sleep(500)\n...(5)> end\niex(6)> spawn(fn ->\n...(6)>  {:ok, client} = EdgeDB.start_link()\n...(6)>  EdgeDB.transaction(client, &callback.(&1, \"new_body_1\"))\n...(6)> end)\niex(7)> EdgeDB.transaction(client, &callback.(&1, \"new_body_2\"), retry: [transaction_conflict: [attempts: 0]])\n** (EdgeDB.Error) TransactionSerializationError: could not serialize access due to concurrent update\n```\n\nNow let's execute the same thing but with enabled retries:\n\n```iex\niex(8)> spawn(fn ->\n...(8)>  {:ok, client} = EdgeDB.start_link()\n...(8)>  EdgeDB.transaction(client, &callback.(&1, \"new_body_1\"))\n...(8)> end)\niex(9)> EdgeDB.transaction(client, &callback.(&1, \"new_body_2\"))\n{:ok, :ok}\n```\n\nAll failed transactions will be retried until they succeed or until the number of retries exceeds the limit (the default is 3).","ref":"usage.html#transactions"},{"type":"extras","title":"Example - Usage","doc":"You can also check out an example application using this client to see how to work with it:\n\nhttps://github.com/nsidnev/edgebeats","ref":"usage.html#example"},{"type":"extras","title":"Datatypes","doc":"# Datatypes\n\nEdgeDB client for Elixir automatically converts EdgeDB types to the corresponding Elixir types and vice versa.\n\nThe table below shows the correspondence between EdgeDB and Elixir types.\n\n| EdgeDB                                   | Elixir                                   | Example                                              |\n| ---------------------------------------- | ---------------------------------------- | ---------------------------------------------------- |\n| `std::str`                               | `t:String.t/0`                           | `\"Hello EdgeDB!\"`                                    |\n| `std::int16`, `std::int32`, `std::int64` | `t:integer/0`                            | `16`                                                 |\n| `std::float32`, `std::float64`           | `t:float/0`                              | `3.1415`                                             |\n| `std::bigint`, `std::decimal`            | `t:Decimal.t/0`                          | `#Decimal<1.23>`                                     |\n| `std::bool`                              | `t:boolean/0`                            | `true`, `false`                                      |\n| `std::datetime`                          | `t:DateTime.t/0`                         | `~U[2018-05-07 15:01:22Z]`                           |\n| `std::duration`                          | `t:integer/0` or `Timex.Duration`        | `-420000000`, `# `                    |\n| `cal::local_datetime`                    | `t:NaiveDateTime.t/0`                    | `~N[2018-05-07 15:01:22]`                            |\n| `cal::local_date`                        | `t:Date.t/0`                             | `~D[2018-05-07]`                                     |\n| `cal::local_time`                        | `t:Time.t/0`                             | `~T[15:01:22]`                                       |\n| `cal::relative_duration`                 | `t:EdgeDB.RelativeDuration.t/0`          | `#EdgeDB.RelativeDuration<\"PT45.6S\">`                |\n| `cal::date_duration`                     | `t:EdgeDB.DateDuration.t/0`              | `#EdgeDB.DateDuration<\"P4Y12D\">`                     |\n| `std::json`                              | `t:any/0`                                | `42`                                                 |\n| `std::uuid`                              | `t:String.t/0`                           | `\"0eba1636-846e-11ec-845e-276b0105b857\"`             |\n| `std::bytes`                             | `t:binary/0`                             | `<<1, 2, 3>>`, `\"some bytes\"`                        |\n| `cfg::memory`                            | `t:EdgeDB.ConfigMemory.t/0`              | `#EdgeDB.ConfigMemory<\"5KiB\">`                       |\n| `ext::pgvector::vector`                  | `t:list/0`                               | `[1.5, 2.0, 4.5]`                                    |\n| `anyenum`                                | `t:String.t/0`                           | `\"green\"`                                            |\n| `array `                         | `t:list/0`                               | `[1, 2, 3]`                                          |\n| `anytuple`                               | `t:tuple/0` or `t:EdgeDB.NamedTuple.t/0` | `{1, 2, 3}`, `#EdgeDB.NamedTuple }` |\n| `range`                                  | `t:EdgeDB.Range.t/0`                     | `#EdgeDB.Range<[1.1, 3.3)>`                          |\n| `object`                                 | `t:EdgeDB.Object.t/0`                    | `#EdgeDB.Object }`                |\n| `set`                                    | `t:EdgeDB.Set.t/0`                       | `#EdgeDB.Set<{1, 2, 3}>}`                            |","ref":"datatypes.html"},{"type":"extras","title":"Custom codecs for EdgeDB scalars","doc":"# Custom codecs for EdgeDB scalars\n\n`EdgeDB.Protocol.Codec` is a codec that knows how to encode or decode Elixir types into EdgeDB types\n  and vice versa using the EdgeDB binary format.\n\nCustom codecs can be useful when your EdgeDB scalars need their own processing.\n\n> #### NOTE {: .warning}\n>\n> Although most of the client API is complete, some internal parts may be changed in the future.\n>   The implementation of the binary protocol (including the definition of custom codecs) is on the list of possible changes.\n\nIn most cases you can use already defined codecs to work with the EdgeDB binary protocol. Otherwise,\n  you will need to check to the EdgeDB [binary protocol documentation](https://www.edgedb.com/docs/reference/protocol).\n\nTo implement custom codec it will be required to implement `EdgeDB.Protocol.CustomCodec` behaviour\n  and implement `EdgeDB.Protocol.Codec` protocol.\n\nAs an example, let's create a custom codec for a scalar that extends the standard `std::json` type.\n\n```sdl\nmodule default {\n    scalar type JSONPayload extending json;\n\n    type User {\n        required name: str {\n            constraint exclusive;\n        };\n\n        required payload: JSONPayload;\n    }\n};\n```\n\nWe will convert the following structure to `default::JSONPayload`:\n\n```elixir\ndefmodule MyApp.Users.Payload do\n  defstruct [\n    :public_id,\n    :first_name,\n    :last_name\n  ]\n\n  @type t() :: %__MODULE__{\n          public_id: integer(),\n          first_name: String.t(),\n          last_name: String.t()\n        }\nend\n```\n\nThe implementation of the codec itself:\n\n```elixir\ndefmodule MyApp.EdgeDB.Codecs.JSONPayload do\n  @behviour EdgeDB.Protocol.CustomCodec\n\n  defstruct []\n\n  @impl EdgeDB.Protocol.CustomCodec\n  def new do\n    %__MODULE__{}\n  end\n\n  @impl EdgeDB.Protocol.CustomCodec\n  def name do\n    \"default::JSONPayload\"\n  end\nend\n\ndefimpl EdgeDB.Protocol.Codec, for: MyApp.EdgeDB.Codecs.JSONPayload do\n  alias EdgeDB.Protocol.{\n    Codec,\n    CodecStorage\n  }\n\n  alias MyApp.EdgeDB.Codecs.JSONPayload\n  alias MyApp.Users.Payload\n\n  @impl Codec\n  def encode(_codec, %Payload{} = payload, codec_storage) do\n    json_codec = CodecStorage.get_by_name(codec_storage, \"std::json\")\n    Codec.encode(json_codec, Map.from_struct(payload), codec_storage)\n  end\n\n  @impl Codec\n  def encode(_codec, value, codec_storage) do\n    raise EdgeDB.InterfaceError.new(\n            \"unexpected value to encode as #{inspect(JSONPayload.name())}: #{inspect(value)}\"\n          )\n  end\n\n  @impl Codec\n  def decode(_codec, data, codec_storage) do\n    json_codec = CodecStorage.get_by_name(codec_storage, \"std::json\")\n    payload = Codec.decode(json_codec, data, codec_storage)\n    %Payload{\n      public_id: payload[\"public_id\"]\n      first_name: payload[\"first_name\"]\n      last_name: payload[\"last_name\"]\n    }\n  end\nend\n```\n\nNow let's test this codec:\n\n```iex\niex(1)> {:ok, client} = EdgeDB.start_link(codecs: [MyApp.EdgeDB.Codecs.JSONPayload])\niex(2)> payload = %MyApp.Users.Payload{public_id: 1, first_name: \"Harry\", last_name: \"Potter\"}\niex(3)> EdgeDB.query!(client, \"insert User { name :=  $username, payload :=  $payload }\", username: \"user\", payload: payload)\niex(4)> object = EdgeDB.query_required_single!(client, \"select User {name, payload} filter .name = 'user' limit 1\")\n#EdgeDB.Object \n```","ref":"custom-codecs.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Changelog","doc":"[Compare with 0.7.0](https://github.com/edgedb/edgedb-elixir/compare/v0.7.0...HEAD)\n\n## [0.7.0] - 2024-05-05\n\n[Compare with 0.6.1](https://github.com/edgedb/edgedb-elixir/compare/v0.6.1...v0.7.0)","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added - Changelog","doc":"- rendering hints for query errors from EdgeDB.\n- support for EdgeDB binary protocol `2.0`.\n- new `EdgeDB.MultiRange` type to represent multiranges from `EdgeDB 4.0`.\n- `EdgeDB.Object.id/1` to fetch ID from an `EdgeDB.Object` if it was returned from the query.\n- `EdgeDB.ConfigMemory.new/1` to create a new instance of `t:EdgeDB.ConfigMemory.t/0`.\n- support for `Elixir v1.16`.\n- support for branches.\n- support for server name (SNI) passing to TLS connection.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `t:EdgeDB.Object.t/0` to be `opaque`.\n- the behavior of injecting an implicit `:id` field into objects so that this no longer happens.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- client state handling in `EdgeDB.with_config/2`/`EdgeDB.without_config/2`,\n    `EdgeDB.with_globals/2`/`EdgeDB.without_globals/2` and\n    `EdgeDB.with_module_aliases/2`/`EdgeDB.without_module_aliases/2`.\n\n## [0.6.1] - 2023-07-07\n\n[Compare with 0.6.0](https://github.com/edgedb/edgedb-elixir/compare/v0.6.0...v0.6.1)","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- support for `Elixir v1.15` and `Erlang/OTP 26`.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- encoding of `t:EdgeDB.Range.t/0` values.\n- constructing `t:EdgeDB.Range.t/0` from `EdgeDB.Range.new/3` with `nil` as values.\n- examples in the documentation and the `Inspect` implementation of\n    `t:EdgeDB.DateDuration.t/0` and `t:EdgeDB.Range.t/0`.\n\n## [0.6.0] - 2023-06-22\n\n[Compare with 0.5.1](https://github.com/edgedb/edgedb-elixir/compare/v0.5.1...v0.6.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- support for `cal::date_duration` EdgeDB type via `EdgeDB.DateDuration` structure.\n- support for EdgeDB Cloud.\n- support for tuples and named tuples as query arguments.\n- support for `EdgeDB 3.0`.\n- support for `ext::pgvector::vector` type.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- implementation of `Enumerable` protocol for `EdgeDB.Set`.\n- `EdgeDB.State` to `EdgeDB.Client.State`, `EdgeDB.with_state/2` to\n    `EdgeDB.with_client_state/2`, `:state` option to `:client_state`.\n- license from `MIT` to `Apache 2.0`.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- crash after updating `db_connection` to `2.5`.\n- decoding a single propery for `EdgeDB.Object` that equals to an empty set.\n- not catching an `EdgeDB.Error` exception during parameters encoding,\n    which caused throwing an exception for non-`!` functions.\n- silent error for calling `EdgeDB` API with wrong module names.","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Changelog","doc":"- `EdgeDB.subtransaction/2`, `EdgeDB.subtransaction!/2` functions and other mentions of\n    subtransactions support in the client.\n- support for custom pool configuration.\n- `:raw` option from `EdgeDB.query*` functions as well as access to `EdgeDB.Query`\n    and `EdgeDB.Result`.\n- API for constructing an `EdgeDB.Error`.\n\n## [0.5.1] - 2022-08-25\n\n[Compare with 0.5.0](https://github.com/edgedb/edgedb-elixir/compare/v0.5.0...v0.5.1)","ref":"changelog.html#removed"},{"type":"extras","title":"Removed - Changelog","doc":"- unintentional ping log for the connection.\n\n## [0.5.0] - 2022-08-20\n\n[Compare with 0.4.0](https://github.com/edgedb/edgedb-elixir/compare/v0.4.0...v0.5.0)","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- `EdgeDB.Client` module that is acceptable by all `EdgeDB` API.\n- `:max_concurrency` option to start pool to control max connections count in `EdgeDB.Pool`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- default pool from `DBConnection.Pool` to `EdgeDB.Pool`.\n- `EdgeDB.Pool` to be \"real\" lazy and dynamic: all idle connections that EdgeDB wants to drop\n    will be disconnected from the pool, new connections will be created only on user queries\n    depending on EdgeDB concurrency suggest as soft limit and `:max_concurrency` option as hard limit\n    of connections count.\n- first parameter accepted by callbacks in `EdgeDB.transaction/3`, `EdgeDB.subtransaction/2`\n    and `EdgeDB.subtransaction!/2` from `t:DBConnection.t/0` to `t:EdgeDB.Client.t/0`.\n- `EdgeDB.connection/0` to `t:EdgeDB.client/0`.\n- `EdgeDB.edgedb_transaction_option/0` to `t:EdgeDB.Client.transaction_option/0`.\n- `EdgeDB.retry_option/0` to `t:EdgeDB.Client.retry_option/0`.\n- `EdgeDB.retry_rule/0` to `t:EdgeDB.Client.retry_rule/0`.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- concurrent transactions when client was unintentionally marked as borrowed for transaction instead of connection.","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Changelog","doc":"- `EdgeDB.WrappedConnection` module in favor of `EdgeDB.Client`.\n\n## [0.4.0] - 2022-08-04\n\n[Compare with 0.3.0](https://github.com/edgedb/edgedb-elixir/compare/v0.3.0...v0.4.0)","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- support for `EdgeDB 2.0` with new binary protocol.\n- support for EdgeQL state via `EdgeDB.State`.\n- new `EdgeDB.Range` type to represent ranges from `EdgeDB 2.0`.\n- support for multiple EdgeQL statements execution via `EdgeDB.execute/4` and `EdgeDB.execute!/4`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `io_format` option to `output_format`.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- the ability to pass maps or keyword lists in a query that requires positional arguments.\n\n## [0.3.0] - 2022-05-29\n\n[Compare with 0.2.1](https://github.com/edgedb/edgedb-elixir/compare/v0.2.1...v0.3.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- maps as a valid type for query arguments.\n- `EdgeDB.Object.to_map/1` and `EdgeDB.NamedTuple.to_map/1` functions.\n- optional support for `std::datetime` EdgeDB type via `Timex.Duration` structure.\n- custom modules for each EdgeDB exception with the `new/2` function, that will return the `EdgeDB.Error` exception.\n- documentation for `EdgeDB.Error` functions that create new exceptions.","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- legacy arguments encoding.","ref":"changelog.html#removed"},{"type":"extras","title":"Changed - Changelog","doc":"- `EdgeQL` queries to be lowercase.\n- `EdgeDB.Error.inheritor?/2` to work with generated module names for EdgeDB exceptions instead of atoms.\n\n## [0.2.1] - 2022-05-19\n\n[Compare with 0.2.0](https://github.com/edgedb/edgedb-elixir/compare/v0.2.0...v0.2.1)","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- mention of `:repeatable_read` option for transaction isolation mode from `t:EdgeDB.edgedb_transaction_option/0`.","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- codec name returned by codec for `std::str` from `std::uuid` to `str::str`.\n- documentation for the custom codec example, which did not have a `EdgeDB.Protocol.Codec.decode/3` implementation and used the wrong protocol.\n\n## [0.2.0] - 2022-05-03\n\n[Compare with 0.1.0](https://github.com/edgedb/edgedb-elixir/compare/v0.1.0...v0.2.0)","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- `EdgeDB.Object.fields/2`, `EdgeDB.Object.properties/2`, `EdgeDB.Object.links/1` and `EdgeDB.Object.link_properties/1` functions to inspect the fields of the object.\n- `EdgeDB.Error.inheritor?/2` function to check if the exception is an inheritor of another EdgeDB error.\n- `EdgeDB.Sandbox` module for use in tests involving database modifications.\n- `EdgeDB.Pool` to support dynamic resizing of the connection pool via messages from EdgeDB server.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- creation of `EdgeDB.Object` properties equal to an empty `EdgeDB.Set`.\n- access to TLS certificate from connection options.\n- isolation configuration by dropping `REPEATABLE READ` mode, because only `SERIALIZABLE` is supported by `EdgeDB 1.0` (`REPEATABLE READ` was dropped in `EdgeDB 1.3`).\n- preserving the order of the values returned when working with `EdgeDB.NamedTuple` (`EdgeDB.NamedTuple.to_tuple/1`, `EdgeDB.NamedTuple.keys/1`), including `Enumerable` protocol implementation.","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- parsing of binary data from EdgeDB by completely reworking the protocol implementation.\n- internal implementation of the `Access` behaviour for `EdgeDB.Object` to improve fields access performance.\n\n## [0.1.0] - 2022-02-10\n\n[Compare with first commit](https://github.com/edgedb/edgedb-elixir/compare/a9c18f910e36e728eb8d59e6e8e41721474f201c...v0.1.0)","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- First release.","ref":"changelog.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}